@@ -35,7 +35,7 @@ typedef void * _TKEY;
 extern int task_flags;
 void ufr_close_all();
 int ignore_child_flag;
-
+void init_posix_dependent();
 
 #define DTI_LENGTH		10000
 
@@ -197,6 +197,7 @@ int i;
 
 	init_u_fileroot();
 
+	init_posix_dependent();
 }
 
 
