@@ -136,8 +136,8 @@ int _no;
 				goto inv_param;
 			}
 			er = set_matrix_cal_equ(mtx,
-				atoi(n_string(std_cm,no)),
-				atoi(n_string(std_cm,equ)));
+				_no = atoi(n_string(std_cm,no)),
+				_equ = atoi(n_string(std_cm,equ)));
 			if ( er < 0 )
 				return get_error(
 					s->h.file,
@@ -145,6 +145,11 @@ int _no;
 					XLE_PROTO_UNSUTISFIED_INFO,
 					l_string(std_cm,"gmxCreate/gmxPhase"),
 					get_integer(er,0));
+			if ( cw->active_phase_mode >= 0 ) {
+				cw->phase_active[cw->active_phase_mode] = 1;
+				cw->phase[cw->active_phase_mode][_no] =
+					cw->phase[cw->active_phase_mode][_equ];
+			}
 		}
 		else {
 		default_type:
@@ -152,7 +157,7 @@ int _no;
 			if ( get_type(s) == XLT_ERROR )
 				return s;
 			set_gc_bind(env,s);
-			er = set_matrix_cal(mtx,atoi(n_string(std_cm,no)),s);
+			er = set_matrix_cal(mtx,_no = atoi(n_string(std_cm,no)),s);
 			if ( er < 0 )
 				return get_error(
 					s->h.file,
@@ -160,6 +165,10 @@ int _no;
 					XLE_PROTO_UNSUTISFIED_INFO,
 					l_string(std_cm,"gmxCreate/gmxPhase"),
 					get_integer(er,0));
+			if ( cw->active_phase_mode >= 0 ) {
+				cw->phase_active[cw->active_phase_mode] = 1;
+				cw->phase[cw->active_phase_mode][_no] = s;
+			}
 		}
 	}
 	else {
@@ -748,6 +757,7 @@ int er;
 int i;
 L_CHAR * currentPhase_mode;
 XL_SEXP * current_phase[MI_MAX];
+L_CHAR * active_phase_mode;
 
 	cp->m = 0;
 	cp->mode = 0;
@@ -762,6 +772,17 @@ XL_SEXP * current_phase[MI_MAX];
 	neturl = get_sf_attribute(sf,l_string(std_cm,"neturl"));
 	key = get_sf_attribute(sf,l_string(std_cm,"key"));
 	currentPhase_mode = get_sf_attribute(sf,l_string(std_cm,"currentPhase_mode"));
+	active_phase_mode = get_sf_attribute(sf,l_string(std_cm,"activePhase_mode"));
+	if ( active_phase_mode ) {
+		if ( l_strcmp(active_phase_mode,l_string(std_cm,"direct")) == 0 )
+			cw.active_phase_mode = MI_MODE_DIRECT;
+		else if ( l_strcmp(active_phase_mode,l_string(std_cm,"server")) == 0 )
+			cw.active_phase_mode = MI_MODE_SERVER;
+		else if ( l_strcmp(active_phase_mode,l_string(std_cm,"client")) == 0 )
+			cw.active_phase_mode = MI_MODE_CLIENT;
+		else	goto inv_param;
+	}
+	else	cw.active_phase_mode = -1;
 	m = open_matrix(
 		neturl,				// open URL name
 		filename,			// save filename
@@ -775,7 +796,14 @@ XL_SEXP * current_phase[MI_MAX];
 	err_org = load_matrix_header(m,O_CREAT|O_RDWR,0644);
 	if ( err_org == 0 )
 		cw.mode = MXEM_EXIST;
-	else	cw.mode = MXEM_CREATE;
+	else {
+		if ( err_org == ME_CANNOT_OPEN_FILE ) {
+			err_org = load_matrix_header(m,O_RDWR|O_CREAT|O_TRUNC,0644);
+		}
+		if ( err_org == 0 )
+			cw.mode = MXEM_EXIST;
+		else	cw.mode = MXEM_CREATE;
+	}
 
 	p = cp->p;
 	
