@@ -219,7 +219,7 @@ ss_printf("h = %i/%i   \n",h,ppm.pi_height);
 			}
 		}
 		u_write(ppm.pi_fd,write_buffer,ww*3);
-		target[2] += 1<<(target[0]*mx_e->c.m->dim_divide[0]);
+		target[2] += ((INTEGER64)1)<<(target[0]*mx_e->c.m->dim_divide[0]);
 	}
 	
 	mx_e->c.gn_tree_node = gn_tree_node;
