@@ -216,7 +216,7 @@ ss_printf("h = %i/%i   \n",h,ppm.pi_height);
 			else	*vp++ = aa = 1;
 		}
 		write_mx_cache_vector(&p);
-		target[2] += 1<<(target[0]*mx_e->c.m->dim_divide[0]);
+		target[2] += ((INTEGER64)1)<<(target[0]*mx_e->c.m->dim_divide[0]);
 	}
 
 	mx_e->c.gn_tree_node = gn_tree_node;
