@@ -1910,7 +1910,7 @@ extern void (*draw_gb_indicate_task)(TKEY);
 		= d_alloc(sizeof(GB_POINT)*g->level);
 	for ( i = 0 ; i < g->level ; i ++ )
 		ret->draw_gb.pitch_list[i] = g->pitch_list[i];
-	ret->draw_gb.loop_no = g->loop_no;
+	ret->h.loop_no = g->loop_no;
 	ret->draw_gb.onmap_indicate_size = g->onmap_indicate_size;
 	ret->draw_gb.hit_level = g->hit_level;
 	ret->draw_gb.hit_outofcircle = g->hit_outofcircle;
@@ -2407,7 +2407,7 @@ INFO_SCHEME * is;
 	g->matrix_ofs = r->draw_gb.matrix_ofs;
 	for ( i = 0 ; i < r->draw_gb.level ; i ++ )
 		g->pitch_list[i] = r->draw_gb.pitch_list[i];
-	g->loop_no = r->draw_gb.loop_no;
+	g->loop_no = r->h.loop_no;
 	g->onmap_indicate_size = r->draw_gb.onmap_indicate_size;
 	g->hit_level = r->draw_gb.hit_level;
 	g->hit_outofcircle = r->draw_gb.hit_outofcircle;
