@@ -1,6 +1,6 @@
 /**********************************************************************
  
-	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
+	Copyright (C) 2003-2007 Hirohisa MORI <joshua@globalbase.org>
  
 	This program is free software; you can redistribute it 
 	and/or modify it under the terms of the GLOBALBASE 
@@ -20,6 +20,7 @@
 #include	"xlerror.h"
 #include	"xl.h"
 #include	"resource.h"
+#include	"mx_format.h"
 
 int lock_pdb_lock_p;
 extern int  res_lock_p;
@@ -1021,7 +1022,11 @@ RESOURCE *
 get_resource_ptr(XL_SEXP ** retp,XLISP_ENV * e,XL_FILE * f,int ln)
 {
 XL_SEXP * ret;
-	ret = eval(e,get_symbol(l_string(std_cm,"__resource")));
+XL_SEXP * sym;
+	sym = get_symbol(l_string(std_cm,"__resource"));
+	sym->h.file = f;
+	sym->h.line = ln;
+	ret = eval(e,sym);
 	switch ( get_type(ret) ) {
 	case XLT_ERROR:
 		*retp = ret;
@@ -1497,5 +1502,3 @@ end:
 	free_url(&u);
 	return ret;
 }
-
-
