@@ -266,8 +266,10 @@ L_CHAR * url;
 		}
 
 		INIT_RING(&r->map.point_list);
-		r->map.param_reverse.type = 0;
-		r->map.param_forward.type = 0;
+		r->map.param_reverse.type = MT_MOVE;
+		r->map.param_forward.type = MT_MOVE;
+		r->map.param_reverse.resolution_rate = 1;
+		r->map.param_forward.resolution_rate = 1;
 	case NR_KEEP:
 		;
 	}
