@@ -208,6 +208,8 @@ int key;
 	r->h.p_list = 0;
 	r->h.mtx_loading = 0;
 	r->h.mtx = 0;
+	r->h.vm = 0;
+	r->h.non_setup_vm = 1;
 	zero_c_unit(&r->h.cu);
 
 	copy_url(&r->h.entry,entry);
