@@ -44,6 +44,7 @@ SEM bw_lock;
 BW_MAP bw_map;
 int draw_map_flag = 0;
 
+extern XLISP_ENV * gv_env[RID_SP_MAX];
 extern SEM res_lock;
 
 #define BWT_ROUTE	3
@@ -53,6 +54,8 @@ void browse_children_map_task();
 XL_SEXP * gv_set_status_coordinate_gbview();
 int close_coord(RESOURCE * r);
 
+XL_SEXP *
+gv_toggle_mapping_info(XLISP_ENV *,XL_SEXP *,XLISP_ENV *,XL_SYM_FIELD *);
 
 void
 init_coordinate_browse()
@@ -71,6 +74,14 @@ extern XLISP_ENV * gv_resource_env[];
 	set_env(e,l_string(std_cm,"gv-set-status"),
 			get_func_prim(gv_set_status_coordinate_gbview,
 			FO_APPLICATIVE,0,1,-1));
+			
+	
+	e = gv_env[RID_INIT];
+	if ( e == 0 )
+		er_panic("init_coordinate_browse");
+	set_env(e,l_string(std_cm,"gv-toggle-mapping-information"),
+			get_func_prim(gv_toggle_mapping_info,
+			FO_APPLICATIVE,0,1,1));
 }
 
 void
@@ -435,7 +446,11 @@ LOAD_RESOURCE_WORK * wp;
 			}
 			insert_parent_list(r,m->map_file);
 			ret = 1;
-			this_coord = 1;
+			
+			if ( m->src )
+				this_coord = 1;
+
+//ss_printf("MAP OK %ls\n",get_url_str2(&m->map_url));
 		}
 
 /***/
@@ -468,10 +483,12 @@ LOAD_RESOURCE_WORK * wp;
 				goto err;
 			insert_parent_list(r,m->src);
 			ret = 1;
-			this_coord = 1;
+			if ( m->map_file )
+				this_coord = 1;
 			if ( m->src->h.notes )
 				call_gv_event(m->src->h.no,
 					l_string(std_cm,"set-note"));
+//ss_printf("SRC OK %ls\n",get_url_str2(&m->src_url));
 		}
 
 
@@ -499,6 +516,7 @@ LOAD_RESOURCE_WORK * wp;
 
 	}
 	if ( this_coord ) {
+/*
 	WF_ID wfid;
 	GBVIEW_FLAME * gf;
 		gf = wf_search(&wfid,r);
@@ -506,6 +524,10 @@ LOAD_RESOURCE_WORK * wp;
 			win_flame_dirty(gf,wfid,0,
 				WFF_DIRTY|WFF_LS_DIRTY,
 				0);
+*/
+		wf_insert_dirty_rect(r,
+				&r->h.minrect,WFF_DIRTY,120,10);
+		force_change_task();
 	}
 	return ret;
 }
@@ -1197,6 +1219,16 @@ rect_cnt ++;
 		default:
 			er_panic("no support");
 		}
+		if ( dw1.limit_reso >= 0 ) {
+			map_conv_forward(m1->map_file,
+				&dw1.limit_ptr,
+				&dw1.limit_reso,1);
+			if ( dw1.limit_reso >= 0 ) {
+				if ( dw->limit_reso == 0 ||
+					dw->limit_reso < dw1.limit_reso )
+				dw->limit_reso = dw1.limit_reso;
+			}
+		}
 		if ( draw_map_flag ) {
 			dw1 = *dw;
 			dw1.parent = dw;
@@ -1216,16 +1248,6 @@ rect_cnt ++;
 			dw->flags |= dw1.flags;
 			dw->data_request += dw1.data_request;
 		}
-		if ( dw1.limit_reso >= 0 ) {
-			map_conv_forward(m1->map_file,
-				&dw1.limit_ptr,
-				&dw1.limit_reso,1);
-			if ( dw1.limit_reso >= 0 ) {
-				if ( dw->limit_reso == 0 ||
-					dw->limit_reso < dw1.limit_reso )
-				dw->limit_reso = dw1.limit_reso;
-			}
-		}
 
 		unlock_task(res_lock,"draw_coordinate");
 		if ( wf_active_check_2(gf,dw->wfid) < 0 ) {
@@ -1442,3 +1464,40 @@ retry:
 	unlock_task(res_lock,"check_coordinate");
 	return 0;
 }
+
+
+XL_SEXP *
+gv_toggle_mapping_info(XLISP_ENV * e,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
+{
+L_CHAR * mode;
+	mode = get_sf_attribute(sf,l_string(std_cm,"mode"));
+	if ( mode == 0 )
+		goto toggle;
+	if ( l_strcmp(mode,l_string(std_cm,"toggle")) == 0 ) {
+	toggle:
+		draw_map_flag = 1 - draw_map_flag;
+		set_draw_mapping(draw_map_flag,1);
+	}
+	else if ( l_strcmp(mode,l_string(std_cm,"on")) == 0 ) {
+		draw_map_flag = 1;
+		set_draw_mapping(draw_map_flag,1);
+	}
+	else if ( l_strcmp(mode,l_string(std_cm,"off")) == 0 ) {
+		draw_map_flag = 0;
+		set_draw_mapping(draw_map_flag,1);
+	}
+	else if ( l_strcmp(mode,l_string(std_cm,"status")) == 0 ) {
+		draw_map_flag = set_draw_mapping(-1,0);
+	}
+	else {
+		return get_error(
+			s->h.file,
+			s->h.line,
+			XLE_PROTO_INV_PARAM,
+			l_string(std_cm,"gv-toggle-mapping-info"),
+			List(n_get_string("invalid mode attribute"),
+				get_string(mode),-1));
+	}
+	return get_integer(draw_map_flag,0);
+}
+
