@@ -28,6 +28,12 @@
 #include	"win_flame.h"
 #include	"queue.h"
 
+/*
+#define DRAW_DEBUG
+*/
+#define SC_OFFSET	0
+#define SC_RATE		0.6
+
 #define THPUT_TH		16000
 #define DM_HANGING_TIME		10
 #define DM_LIST_SIZE		35
@@ -145,7 +151,7 @@ void indicate_md_by_large();
 	pipe0.gc_func = gc_dm_t;
 	pipe0.gc_get = gc_get_dm_t;
 	pipe0.key_func = dm_loading_task0;
-	pipe0.pri = PRI_FETCH_STRONG;
+	pipe0.pri = PRI_FETCH;
 	pipe0.key_limit = 5;
 	setup_queue(&pipe0);
 
@@ -154,7 +160,7 @@ void indicate_md_by_large();
 	pipe1.gc_func = gc_dm_t;
 	pipe1.gc_get = gc_get_dm_t;
 	pipe1.key_func = dm_loading_task2;
-	pipe1.pri = PRI_FETCH_STRONG;
+	pipe1.pri = PRI_FETCH;
 	pipe1.key_limit = 10;
 	setup_queue(&pipe1);
 
@@ -171,7 +177,7 @@ void indicate_md_by_large();
 
 	INIT_RING(&dm_h);
 
-	create_task(dm_scan_task,0,PRI_FETCH_STRONG);
+	create_task((void(*)(TKEY))dm_scan_task,0,PRI_FETCH_STRONG);
 /*
 	create_task(dm_loading_task0,0,PRI_FETCH);
 	create_task(dm_loading_task1,0,PRI_FETCH);
@@ -473,6 +479,11 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 			r->draw_gb.tile_dirty_rect.br.x
 				= r->draw_gb.tile_dirty_rect.br.y = -1;
 			unlock_pdb_lock(r);
+#ifdef DRAW_DEBUG
+ss_printf("START = ");
+print_sexp(s_stdout,ld,0);
+ss_printf("\n");
+#endif
 			for ( ; get_type(ld) == XLT_PAIR &&
 				get_type(cdr(ld)) != XLT_NULL ;
 				ld = cdr(ld) );
@@ -480,6 +491,11 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 				set_init_status_error(r,0);
 			}
 			else {
+#ifdef DRAW_DEBUG
+ss_printf("END = ");
+print_sexp(s_stdout,ld,0);
+ss_printf("\n");
+#endif
 				ret = eval(e,car(ld));
 				if ( get_type(ret) == XLT_ERROR ) {
 					set_init_status_error(r,ret);
@@ -613,8 +629,8 @@ int ret;
 	ret = 0;
 	for ( ; dm != (DRAW_MATRIX*)&dm_h ;
 			dm = R_NEXT(DRAW_MATRIX*,&dm->h) ) {
-		if ( dm->loop_no <= dm->r->draw_gb.loop_no
-				- spiral_count - 2 )
+		if ( dm->loop_no <= dm->r->h.loop_no
+				- (spiral_count*SC_RATE + SC_OFFSET) )
 			continue;
 		if ( dm->flags & DMF_REQUEST )
 			ret ++;
@@ -790,12 +806,12 @@ max_size);
 	}
 
 	set_inc_status(r,RS_LOAD);
-/*
+#ifdef DRAW_DEBUG
 printf("query = ");
 fflush(stdout);
 print_sexp(s_stdout,query,0);
 ss_printf("\n");
-*/
+#endif
 
 
 	ret = remote_session(
@@ -900,15 +916,16 @@ int i;
 						0),
 					-1),
 				-1);
-/*
+#ifdef DRAW_DEBUG
 ss_printf("TARGET %ls\n\n",get_url_str2(&r->h.target));
 ss_printf("RCT (%f %f) (%f %f)\n%f %f\n",
 rct->tl.x,rct->tl.y,
 rct->br.x,rct->br.y,
 rct->br.x - rct->tl.x,
 rct->br.y - rct->tl.y);
-*/
-
+print_sexp(s_stdout,query,0);
+ss_printf("\n");
+#endif
 	set_inc_status(r,RS_LOAD);
 
 	ret = remote_session(
@@ -1231,8 +1248,8 @@ int ht;
 		dm = R_NEXT(DRAW_MATRIX*,&dm->h) ) {
 		if ( !(dm->flags & DMF_REQUEST) )
 			continue;
-		if ( dm->loop_no <= dm->r->draw_gb.loop_no
-				- spiral_count - 2 ) {
+		if ( dm->loop_no <= dm->r->h.loop_no
+				- (spiral_count*SC_RATE + SC_OFFSET) ) {
 			dm->flags &= ~DMF_REQUEST;
 			continue;
 		}
@@ -1262,8 +1279,8 @@ next:
 			continue;
 		if ( !(dm->flags & DMF_REQUEST) )
 			continue;
-		if ( dm->loop_no <= dm->r->draw_gb.loop_no
-				- spiral_count - 2 ) {
+		if ( dm->loop_no <= dm->r->h.loop_no
+				- (spiral_count*SC_RATE + SC_OFFSET) ) {
 			dm->flags &= ~DMF_REQUEST;
 			continue;
 		}
@@ -1292,8 +1309,8 @@ SERVER_INFO si;
 		dm = R_NEXT(DRAW_MATRIX*,&dm->h) ) {
 		if ( !(dm->flags & DMF_REQUEST) )
 			continue;
-		if ( dm->loop_no <= dm->r->draw_gb.loop_no
-				- spiral_count - 2 ) {
+		if ( dm->loop_no <= dm->r->h.loop_no
+				- (spiral_count*SC_RATE + SC_OFFSET) ) {
 			dm->flags &= ~DMF_REQUEST;
 			continue;
 		}
@@ -1427,7 +1444,7 @@ int i,j;
 		}
 	dm1->flags = 0;
 	dm1->wfid = wfid;
-	dm1->loop_no = r->draw_gb.loop_no;
+	dm1->loop_no = r->h.loop_no;
 	dm1->access = get_ac_time();
 	dm_nos ++;
 	INSERT_RING(&dm_h,&dm1->h);
@@ -1456,7 +1473,7 @@ SI_GBVIEW g;
 	INSERT_RING(&dm_h,&dm->h);
 	dm->access = get_ac_time();
 	dm->r = res;
-	dm->loop_no = res->draw_gb.loop_no;
+	dm->loop_no = res->h.loop_no;
 
 
 	if ( dm->level == lev && !(dm->flags & DMF_LOADED) ) {
