@@ -1,6 +1,6 @@
 /**********************************************************************
  
-	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
+	Copyright (C) 2003-2007 Hirohisa MORI <joshua@globalbase.org>
  
 	This program is free software; you can redistribute it 
 	and/or modify it under the terms of the GLOBALBASE 
@@ -32,6 +32,7 @@
 #include	"win_flame.h"
 #include	"machine/include.h"
 #include	"mx_format.h"
+#include	"pg_vector.h"
 
 typedef struct pixel_req {
 	struct pixel_req *	next;
@@ -52,9 +53,9 @@ void clean_prq(PIXEL_REQ * pr);
 void purge_prq(PIXEL_REQ * pr);
 void set_pixel_dirty(PIXEL_REQ * pr);
 
-
 extern SEM luster_lock,tc_lock;
 extern XLISP_ENV * gv_resource_env[];
+extern XLISP_ENV * luster_cmd;
 PIXEL_REQ *	pixel_req_queue;
 PIXEL_REQ * 	prq_free;
 int queue_length;
@@ -64,6 +65,32 @@ int get_pixel_cr();
 int get_query_r64();
 int get_query_cr();
 int exit_lock_luster();
+void
+draw_pixel_data_2(
+	VIEW_METHOD * vm,
+	GBVIEW_FLAME * gf,
+	RESOURCE* r,
+	DRAW_WORK * dw);
+int
+vmt_create_draw_pixel(VIEW_METHOD*,MATRIX_NODE *);
+void
+vmt_dummy(VIEW_METHOD* vm,GBVIEW_FLAME* gf,RESOURCE * r,DRAW_WORK* dw);
+
+extern VIEW_METHOD_TBL vm_plot_tbl;
+
+VIEW_METHOD_TBL vm_rgb_tbl = {
+	MDT_RGB8|MDT_VECTOR,0,
+	vmt_create_draw_pixel,
+	0,
+	draw_pixel_data_2,
+	0
+};
+
+VIEW_METHOD_TBL * pixel_vm[] = {
+	&vm_rgb_tbl,
+	&vm_plot_tbl,
+	0
+};
 
 void
 init_luster_r64()
@@ -71,12 +98,14 @@ init_luster_r64()
 XLISP_ENV * l_top;
 XL_SEXP * gv_set_visible_resolution();
 	init_luster();
+	vm_tbl[RT_PIXEL_MAP_R64] = pixel_vm;
 	l_top = gv_resource_env[RT_PIXEL_MAP_R64];
 	if ( l_top == 0 )
 		goto next;
 	set_env(l_top,l_string(std_cm,"set-visible-resolution"),
 			get_func_prim(gv_set_visible_resolution,
 			FO_APPLICATIVE,0,2,2));
+	init_pg_vector(luster_cmd);
 next:
 /*
 	create_task(pixel_req_task,0,PRI_FETCH);
@@ -154,7 +183,7 @@ PIXEL_REQ * pr;
 		prq_free = pr->next;
 	}
 	else	pr = d_alloc(sizeof(*pr));
-	pr->loop_no = r->pr64.loop_no;
+	pr->loop_no = r->h.loop_no;
 	pr->wfid = wfid;
 	pr->r = r;
 	pr->x = x;
@@ -294,7 +323,7 @@ int i;
 			lock_task(luster_lock);
 		}
 		pr = delete_pixel_req();
-		if ( pr->loop_no < pr->r->pr64.loop_no - spiral_count - 2 ) {
+		if ( pr->loop_no < pr->r->h.loop_no - spiral_count - 2 ) {
 			purge_prq(pr);
 			unlock_task(luster_lock,"pixel_req_task");
 			continue;
@@ -371,7 +400,7 @@ int clr;
 	d = get_matrix_node_channel
 			(&err,&cache->n,r->h.mtx,
 			&dim_code[0],CH_VISU,
-			GN_TREE,GN_NODE_CREATE,0);
+			GN_TREE,GN_NODE_CREATE,0,r->h.loop_no);
 	if ( d == 0 ) {
 		if ( nn && clr == 0 ) {
 			matrix_node_channel_unlock(nn,0);
@@ -424,10 +453,10 @@ unsigned int r,g,b;
 
 
 unsigned long
-get_mtx_data_2(MTX_CACHE * cache,RESOURCE * r,INTEGER64 lev,INTEGER64 x,INTEGER64 y,INTEGER64 * lev_p);
+get_mtx_data_2(VIEW_METHOD * vm,MTX_CACHE * cache,RESOURCE * r,INTEGER64 lev,INTEGER64 x,INTEGER64 y,INTEGER64 * lev_p);
 
 unsigned long
-get_mtx_data_2(MTX_CACHE * cache,RESOURCE * r,INTEGER64 lev,INTEGER64 x,INTEGER64 y,INTEGER64 * lev_p)
+get_mtx_data_2(VIEW_METHOD * vm,MTX_CACHE * cache,RESOURCE * r,INTEGER64 lev,INTEGER64 x,INTEGER64 y,INTEGER64 * lev_p)
 {
 int err;
 void * d;
@@ -455,10 +484,18 @@ int clr;
 	dim_code[2] = y;
 //ss_printf("get_mtx_data-1\n");
 
-	d = get_matrix_node_channel
-			(&err,&cache->n,r->h.mtx,
-			&dim_code[0],r->h.visu_channel,
-			GN_TREE,GN_NODE_CREATE,0);
+	if ( r->h.mtx->p.flags & MPF_NODE_DIPENDENT ) {
+		d = get_matrix_node_channel
+				(&err,&cache->n,r->h.mtx,
+				&dim_code[0],vm->view_channel[0],
+				GN_TREE,GN_NODE_CREATE,0,r->h.loop_no);
+	}
+	else {
+		d = get_matrix_node_channel
+				(&err,&cache->n,r->h.mtx,
+				&dim_code[0],vm->view_channel[0],
+				GN_TREE,GN_STEP_NODE_CREATE,0,r->h.loop_no);
+	}
 	if ( d == 0 ) {
 		if ( nn && clr == 0 ) {
 			matrix_node_channel_unlock(nn,0);
@@ -520,7 +557,7 @@ int tim,tim2;
 
 	dw->limit_reso = r->pr64.dpm;
 	dw->limit_ptr = dw->pt_list[dw->size/2];
-	r->pr64.loop_no ++;
+	r->h.loop_no ++;
 	dw->flags |= WFF_LUSTER; 
 	dpm1 = r->pr64.dpm;
 	dpm2 = dpm1;
@@ -637,6 +674,7 @@ int tim,tim2;
 
 void
 draw_pixel_data_2(
+	VIEW_METHOD * vm,
 	GBVIEW_FLAME * gf,
 	RESOURCE* r,
 	DRAW_WORK * dw)
@@ -677,7 +715,7 @@ int int_divide;
 
 	dw->limit_reso = r->pr64.dpm;
 	dw->limit_ptr = dw->pt_list[dw->size/2];
-	r->pr64.loop_no ++;
+	r->h.loop_no ++;
 	dw->flags |= WFF_LUSTER; 
 	dpm1 = r->pr64.dpm;
 	dpm2 = dpm1;
@@ -751,8 +789,8 @@ int int_divide;
 					cache.tl_y <= yy && yy < cache.br_y ) {
 				if ( cache.level == lev ) {
 
-					lx = (xx>>(lev*int_divide))&((1<<mtx->block_size[0])-1);
-					ly = (yy>>(lev*int_divide))&((1<<mtx->block_size[1])-1);
+					lx = (xx>>(lev*int_divide))&((((INTEGER64)1)<<mtx->block_size[0])-1);
+					ly = (yy>>(lev*int_divide))&((((INTEGER64)1)<<mtx->block_size[1])-1);
 					if ( lx >= cache.ds.ix[0] ) {
 						cc = C_TRANSPARENT;
 					}
@@ -763,8 +801,8 @@ int int_divide;
 						ly*cache.ds.ix[0]]);
 				}
 				else if ( cache.leaf ) {
-					lx = (xx>>(cache.level*int_divide))&((1<<mtx->block_size[0])-1);
-					ly = (yy>>(cache.level*int_divide))&((1<<mtx->block_size[1])-1);
+					lx = (xx>>(cache.level*int_divide))&((((INTEGER64)1)<<mtx->block_size[0])-1);
+					ly = (yy>>(cache.level*int_divide))&((((INTEGER64)1)<<mtx->block_size[1])-1);
 					if ( lx >= cache.ds.ix[0] ) {
 						cc = C_TRANSPARENT;
 					}
@@ -784,7 +822,7 @@ int int_divide;
 		else {
 		non_cache:
 //			cc = _tc_get_pixel(&r->pr64.tc,level,xx,yy,&lev);
-			cc = get_mtx_data_2(&cache,r,level,xx,yy,&lev);
+			cc = get_mtx_data_2(vm,&cache,r,level,xx,yy,&lev);
 //ss_printf("CC %lli %lli %lli %x\n",xx,yy,level,cc);
 			if ( level != lev && cache.leaf == 0 )
 				dw->data_request ++;
@@ -806,6 +844,14 @@ int int_divide;
 
 }
 
+int
+vmt_create_draw_pixel(VIEW_METHOD* vm,MATRIX_NODE *n)
+{
+	vm->work = 0;
+	return 0;
+}
+
+
 
 void
 draw_pixel_data(
@@ -813,9 +859,17 @@ draw_pixel_data(
 	RESOURCE* r,
 	DRAW_WORK * dw)
 {
+VIEW_METHOD * vm;
 	switch ( r->pr64.type ) {
 	case 'M':
-		draw_pixel_data_2(gf,r,dw);
+//		draw_pixel_data_2(gf,r,dw);
+		if ( r->h.vm == 0 ) {
+			vmt_dummy(0,gf,r,dw);
+		}
+		else {
+			for ( vm = r->h.vm ; vm ; vm = vm->next )
+				(*vm->tbl->vmt_draw)(vm,gf,r,dw);
+		}
 		break;
 	default:
 		draw_pixel_data_1(gf,r,dw);
@@ -850,7 +904,7 @@ int tim,tim2;
 
 	dw->limit_reso = r->pr64.dpm;
 	dw->limit_ptr = dw->pt_list[dw->size/2];
-	r->pr64.loop_no ++;
+	r->h.loop_no ++;
 	dw->flags |= WFF_LUSTER; 
 	dpm1 = r->pr64.dpm;
 	dpm2 = dpm1;
