@@ -149,8 +149,10 @@ int y_index_gf;
 			f = 1;
 		}
 	}
-	if ( f )
+	if ( f ) {
+//		_wf_set_delay_redraw(gf);
 		new_tick((void(*)(int))_wf_set_redraw,0,(int)gf);
+	}
 }
 
 
@@ -377,6 +379,7 @@ end:
 	d_f_ree(pt_list);
 	d_f_ree(pt_reso);
 	free_mh(mh);
+	wf_set_delay_redraw_exec(gf);
 	return 0;
 }
 
@@ -542,10 +545,9 @@ xx,yy,t,b,l,r);
 		}
 		sc ++;
 	}
-	spiral_count = sc;
 end:
-	if ( spiral_count )
-		_set_pri_adj(gf,wf,pri_cnt*PRI_OFFSET_RATE/spiral_count);
+	if ( sc )
+		_set_pri_adj(gf,wf,pri_cnt*PRI_OFFSET_RATE/sc);
 	else	_set_pri_adj(gf,wf,pri_cnt);
 
 	return ret;
@@ -816,15 +818,63 @@ REAL1 rw,rh;
 		rw = 2*gf->win_width;
 	if  (rh > 2*gf->win_height )
 		rh = 2*gf->win_height;
-	r.tl.x = center.x - rw*rate;
-	r.br.x = center.x + rw*rate;
-	r.tl.y = center.y - rh*rate;
-	r.br.y = center.y + rh*rate;
+	rw = rw*rate;
+	rh = rh*rate;
+	r.tl.x = center.x - rw;
+	r.br.x = center.x + rw;
+	r.tl.y = center.y - rh;
+	r.br.y = center.y + rh;
 	
-	ret.tl.x = floor(r.tl.x);
-	ret.tl.y = floor(r.tl.y);
-	ret.br.x = ceil(r.br.x);
-	ret.br.y = ceil(r.br.y);
+	if ( rw > 0x20000000 )
+		rw = 0x20000000;
+	if ( rh > 0x20000000 )
+		rh = 0x20000000;
+	
+	if ( r.tl.x < (REAL1)(-0x7fffffff) ) {
+	hem1:
+		ret.tl.x = 0x7fffffff;
+		ret.br.x = ret.tl.x + 2*rw;
+	}
+	else if ( r.tl.x > (REAL1)0x7fffffff ) {
+	hem2:
+		ret.br.x = 0x7fffffff;
+		ret.tl.x = ret.br.x - 2*rw;
+	}
+	else if ( r.br.x < (REAL1)(-0x7fffffff) ) {
+		goto hem1;
+	}
+	else if ( r.br.x > (REAL1)(0x7fffffff) ) {
+		goto hem2;
+	}
+	else {
+		ret.tl.x = floor(r.tl.x);
+		ret.br.x = ceil(r.br.x);
+	}
+	
+	if ( r.tl.y < (REAL1)(-0x7fffffff) ) {
+	hem3:
+		ret.tl.y = 0x7fffffff;
+		ret.br.y = ret.tl.y + 2*rh;
+	}
+	else if ( r.tl.y > (REAL1)(0x7fffffff) ) {
+	hem4:
+		ret.br.y = 0x7fffffff;
+		ret.tl.y = ret.br.y - 2*rh;
+	}
+	else if ( r.br.y < (REAL1)(-0x7fffffff) ) {
+		goto hem3;
+	}
+	else if ( r.br.y > (REAL1)(0x7fffffff) ) {
+		goto hem4;
+	}
+	else {
+		ret.tl.y = floor(r.tl.y);
+		ret.br.y = ceil(r.br.y);
+	}
+
+if ( ret.tl.x < -2000000000 )
+ss_printf("STOP\n");
+
 	return ret;
 }
 
@@ -835,6 +885,9 @@ int x,y;
 int width;
 unsigned long * d_ptr;
 int ret;
+
+if ( dest_rct.tl.y < -0x800000 )
+ss_printf("copy_small_rect");
 	ret = 0;
 	d_ptr = dest;
 	width = src_rct.br.x - src_rct.tl.x;
