@@ -31,7 +31,7 @@ _main(int argc,char ** argv)
 {
 
 	init_xl(INI_DONTWAITCHI);
-	init_favt64();
+	init_l_favt64();
 	int_handler = 0;
 
 	init_matrix();
