@@ -102,27 +102,29 @@ typedef struct gvha_ids {
 #define IDS_GF	2
 
 typedef struct gvha_query {
-	unsigned	mode:5;
-#define GVHA_NREQ_FRAME_CACHE	0x10
+	unsigned	mode:10;
+#define GVHA_NREQ_FRAME_CACHE	0x100
 #define GVHA_MODE_MOVE		1
 #define GVHA_MODE_INFO1		2
 #define GVHA_MODE_INFO2		3
 #define GVHA_MODE_RSS		4
 #define GVHA_MODE_RSS_SHORT	5
 #define GVHA_MODE_RSS_TINNY	6
+#define GVHA_MODE_RSS_LARGE	7
 
-#define GVHA_MODE_ECT_LOW	7
+#define GVHA_MODE_ECT_LOW	8
 
-#define GVHA_MODE_ECT_OPEN	(8|GVHA_NREQ_FRAME_CACHE)
-#define GVHA_MODE_ECT_INSERT	9
-#define GVHA_MODE_ECT_UPDATE	(10|GVHA_NREQ_FRAME_CACHE)
-#define GVHA_MODE_ECT_DELETE	(11|GVHA_NREQ_FRAME_CACHE)
-#define GVHA_MODE_ECT_MOVE	12
-#define GVHA_MODE_ECT_SAVE	(13|GVHA_NREQ_FRAME_CACHE)
-#define GVHA_MODE_ECT_CLOSE	(14|GVHA_NREQ_FRAME_CACHE)
-#define GVHA_MODE_ECT_OBJECT	(15|GVHA_NREQ_FRAME_CACHE)
+#define GVHA_MODE_ECT_OPEN	(9|GVHA_NREQ_FRAME_CACHE)
+#define GVHA_MODE_ECT_INSERT	10
+#define GVHA_MODE_ECT_UPDATE	(11|GVHA_NREQ_FRAME_CACHE)
+#define GVHA_MODE_ECT_DELETE	(12|GVHA_NREQ_FRAME_CACHE)
+#define GVHA_MODE_ECT_MOVE	13
+#define GVHA_MODE_ECT_SAVE	(14|GVHA_NREQ_FRAME_CACHE)
+#define GVHA_MODE_ECT_CLOSE	(15|GVHA_NREQ_FRAME_CACHE)
+#define GVHA_MODE_ECT_OBJECT	(16|GVHA_NREQ_FRAME_CACHE)
+
+#define GVHA_MODE_ECT_HIGH	17
 
-#define GVHA_MODE_ECT_HIGH	16
 
 	unsigned	complete:1;
 	GVHA_POS	pos;
@@ -1302,6 +1304,8 @@ int sz;
 					q->mode = GVHA_MODE_ECT_CLOSE;
 				else if ( strcmp(str,"object") == 0 )
 					q->mode = GVHA_MODE_ECT_OBJECT;
+				else if ( strcmp(str,"rss_large") == 0 )
+					q->mode = GVHA_MODE_RSS_LARGE;
 				else	return -12;
 				d_f_ree(str);
 				break;
@@ -2151,6 +2155,9 @@ ss_printf("ENTRY URL %ls == %i\n",ls->entry_url,id);
 	case GVHA_MODE_RSS_TINNY:
 		sprintf(&base[p],"&md=rss_tinny");
 		break;
+	case GVHA_MODE_RSS_LARGE:
+		sprintf(&base[p],"&md=rss_large");
+		break;
 	default:
 		er_panic("get_next_taerget");
 	}
@@ -2321,6 +2328,7 @@ XL_SEXP * ret,* sym,* sym2;
 XL_SEXP * cur, * channel, * item, * item2;
 char * next_target;
 char * rss_target;
+WARP_POINT * wp;
 
 	if ( fp_flag && *fp_flag )
 		gvha_flush_pos(c,fp_flag);
@@ -2374,30 +2382,65 @@ char * rss_target;
 		l_string(std_cm,"rdf:about"),
 		l_string(std_cm,next_target));
 
-	item = List(sym,
-		List(n_get_symbol("title"),
-			n_get_string("GLOBALBASE HTTP GATEWAY"),
-			-1),
-		List(n_get_symbol("link"),
-			n_get_string(next_target),
-			-1),
-		List(n_get_symbol("description"),
-			n_get_string("GLOBALBASE HTTP GATEWAY"),
-			-1),
-		List(n_get_symbol("gb:status1"),
-			get_integer(c->all,0),
-			-1),
-		List(n_get_symbol("gb:status2"),
-			get_integer(c->ls.wf.dirty|q->force_dirty,0),
-			-1),
-		List(n_get_symbol("gb:status-n"),
-			get_integer(q->n,0),
-			-1),
-		cons(n_get_symbol("gb:status-layers"),
-			get_layers_info(&c->sts,q->mode)),
-		cons(n_get_symbol("gb:status-projection-type"),
-			get_integer(c->sts.flame_base_display_map_type,0)),
-		-1);
+	switch ( q->mode ) {
+	case GVHA_MODE_RSS_LARGE:
+		wp = rc_get_warp_point(c->gf->radar_ptr,WPT_CRD);
+
+		item = List(sym,
+			List(n_get_symbol("title"),
+				n_get_string("GLOBALBASE HTTP GATEWAY"),
+				-1),
+			List(n_get_symbol("link"),
+				n_get_string(next_target),
+				-1),
+			List(n_get_symbol("description"),
+				n_get_string("GLOBALBASE HTTP GATEWAY"),
+				-1),
+			List(n_get_symbol("gb:status1"),
+				get_integer(c->all,0),
+				-1),
+			List(n_get_symbol("gb:status2"),
+				get_integer(c->ls.wf.dirty|q->force_dirty,0),
+				-1),
+			List(n_get_symbol("gb:status-n"),
+				get_integer(q->n,0),
+				-1),
+			cons(n_get_symbol("gb:status-layers"),
+				get_layers_info(&c->sts,q->mode)),
+			cons(n_get_symbol("gb:status-projection-type"),
+				get_integer(c->sts.flame_base_display_map_type,0)),
+			List(n_get_symbol("gb:status-warppoint"),
+				wp2sexp(wp),-1),
+			-1);
+		free_warp_point(wp);
+		break;
+	default:
+		item = List(sym,
+			List(n_get_symbol("title"),
+				n_get_string("GLOBALBASE HTTP GATEWAY"),
+				-1),
+			List(n_get_symbol("link"),
+				n_get_string(next_target),
+				-1),
+			List(n_get_symbol("description"),
+				n_get_string("GLOBALBASE HTTP GATEWAY"),
+				-1),
+			List(n_get_symbol("gb:status1"),
+				get_integer(c->all,0),
+				-1),
+			List(n_get_symbol("gb:status2"),
+				get_integer(c->ls.wf.dirty|q->force_dirty,0),
+				-1),
+			List(n_get_symbol("gb:status-n"),
+				get_integer(q->n,0),
+				-1),
+			cons(n_get_symbol("gb:status-layers"),
+				get_layers_info(&c->sts,q->mode)),
+			cons(n_get_symbol("gb:status-projection-type"),
+				get_integer(c->sts.flame_base_display_map_type,0)),
+			-1);
+		break;
+	}
 	item = append(item,
 		plot_element_area_list(g_set,c,q->mode));
 
@@ -3233,6 +3276,7 @@ ss_printf("RSS INFO1 FM = %i\n",c->gf->id);
 	case GVHA_MODE_RSS:
 	case GVHA_MODE_RSS_SHORT:
 	case GVHA_MODE_RSS_TINNY:
+	case GVHA_MODE_RSS_LARGE:
 		get_rc_loading_status(
 			(RADAR_CACHE*)c->gf->radar_ptr,&c->ls.rc);
 		wf_free_status(&c->sts);
