@@ -22,6 +22,7 @@
 #include	"xl.h"
 #include	"queue.h"
 #include	"recordlist64.h"
+//#include	"pg_vector.h"
 
 #define NCACHE_SIZE		100
 #define NHASH_SIZE		(4*NCACHE_SIZE+3)
@@ -190,6 +191,11 @@ typedef struct matrix_channel {
 	void *				data;
 	INTEGER64			data_fofs;
 	struct mx_struct_block *	sb;
+	INTEGER64			update_time[2];
+#define UT_CMP			(-2)
+#define UT_EQU			(-1)
+#define UT_DATA			0
+#define UT_SB			1
 } MATRIX_CHANNEL;
 
 typedef struct matrix_node_header {
@@ -227,6 +233,7 @@ typedef struct matrix_node {
 
 	MATRIX_TOKEN *		wait_token;
 	MATRIX_TOKEN *		process_token;
+	int			process_token_key;
 	INTEGER64		req_level;
 	INTEGER64		last_access;
 
@@ -257,6 +264,8 @@ typedef struct matrix_param {
 #define MPF_SET			0x80000000
 #define MPF_INDEX_HEM		0x00000001
 #define MPF_CACHE_FILE		0x00000002
+#define MPF_NODE_DIPENDENT	0x00000004
+#define MPF_PERMISSION		0x00000008
 	int			total_levels;
 	INTEGER64		modify_time;
 	void			(*open_method)(MATRIX_TOKEN*);
@@ -267,10 +276,11 @@ typedef struct matrix_param {
 	void			(*close_net)(struct matrix *);
 	void			(*new_token)(MATRIX_TOKEN * t,int);
 	void			(*free_token)(MATRIX_TOKEN * t,int);
-	void 			(*trigger)(int ttype,void * t);
+	int 			(*trigger)(int ttype,void * t);
 #define TRT_MATRIX_STANBY	1
 #define TRT_TOKEN		2
-#define TRT_FINISH		3
+#define TRT_CANCEL		3
+#define TRT_FINISH		4
 } MATRIX_PARAM;
 
 #define MPT_NEW_TOKEN_NODE	1
@@ -319,6 +329,7 @@ typedef struct matrix {
 	INTEGER64		last_access;
 
 	MATRIX_SEXP *		mx_env;
+	INTEGER64		obj_id;
 
 	/* for file */
 
@@ -643,10 +654,11 @@ MATRIX
 
 /* get_matrix_node(tree) access patteren */
 
-#define GN_READ_ONLY	(-1)
-#define GN_NODE_CREATE	0
-#define GN_LIST_CREATE	1
-#define GN_ERROR_NORETRY 2
+#define GN_READ_ONLY		(-1)
+#define GN_NODE_CREATE		0
+#define GN_STEP_NODE_CREATE	1
+#define GN_LIST_CREATE		2
+#define GN_ERROR_NORETRY	3
 
 #define GN_TREE		1
 #define GN_NODE		0
@@ -799,7 +811,7 @@ void *
 get_matrix_node_channel(int * errp,MATRIX_NODE ** np,
 		MATRIX * m,INTEGER64 * dim_code,
 		int ch,int type,int access,
-		MATRIX_ALLOC_VECTOR_PARAM*);
+		MATRIX_ALLOC_VECTOR_PARAM*,int pt_key);
 void
 matrix_peano_trigger(
 	MATRIX * m,
@@ -1012,6 +1024,20 @@ int
 mx_scale_of_dim_code(INTEGER64 * start,INTEGER64 * last,MATRIX * m);
 int
 matrix_copy(MATRIX * dest,MATRIX * src,int * ch_list,int copy_flags);
+int
+check_children(MATRIX_NODE * n);
+void
+block_check_sum(char * msg,MATRIX_ALLOC_BLOCK_PARAM * p);
+int
+get_matrix_update_time(MATRIX_NODE * n,int ch,int ix);
+MATRIX_NODE *
+get_matrix_tree(int * errp,MATRIX * m,INTEGER64 * dim_code,int access,int pt_key);
+MATRIX_SEXP *
+new_matrix_sexp(XL_SEXP* s);
+INTEGER64
+get_matrix_obj_id(MATRIX * m);
+void
+init_mxObjID(XLISP_ENV * env);
 
 
 #endif
