@@ -22,8 +22,9 @@
 
 #include	"machine/include.h"
 
+/*
 #define MEMORY_DEBUG
-
+*/
 typedef struct mem_free_info {
 	struct mem_free_info *	next;
 	struct mem_free_info *	time_next;
@@ -58,6 +59,8 @@ void init_d_alloc();
 void *	d_re_alloc(void * ptr,int size);
 #define d_calloc(s,el)	xx_d_calloc((s),(el),__FILE__,__LINE__)
 #define d_f_ree(x)	xx_d_f_ree((x),__FILE__,__LINE__)
+void xx_change_statistics(void * ptr,char * file,int line);
+#define change_statistics(ptr)	xx_change_statistics(ptr,__FILE__,__LINE__)
 
 void _new_mem_hash();
 MEM_LIST * _search_mem_list(char * file,int line);
@@ -72,5 +75,8 @@ void start_alloc_time_list();
 
 extern int enabled_time_list;
 
+void * s_alloc(int);
+void s_free(void*);
+void * s_realloc(void*,int);
 
 #endif
