@@ -20,7 +20,7 @@
 
 #include	"resource.h"
 #include	"matrix.h"
-
+#include	"gbview.h"
 
 typedef struct create_param {
 	MATRIX *		m;
@@ -31,6 +31,7 @@ typedef struct create_param {
 typedef struct create_work {
 	MATRIX *		mtx;
 	int			mode;
+	int			active_phase_mode;
 	char			pri_active[MI_MODE_MAX];
 	int			pri[MI_MODE_MAX][MI_MAX];
 	char			phase_active[MI_MODE_MAX];
@@ -57,6 +58,32 @@ typedef struct mx_entry {
 	int			id;
 } MX_ENTRY;
 
+typedef struct vm_work_header {
+	struct vm_work_header *		next;
+	struct view_method_tbl *	tbl;
+	int				flags;
+#define VMWF_NOT_INITIALIZE		0x00000001
+} VM_WORK_HEADER;
+
+typedef struct view_method {
+	struct view_method *		next;
+	struct view_method_tbl *	tbl;
+	RESOURCE *			r;
+	int				target_channel_nos;
+	int *				view_channel;
+	MATRIX *			m;
+	void *				work;
+} VIEW_METHOD;
+
+typedef struct view_method_tbl {
+	int			mdt_type;
+	MX_STRUCT_BLOCK_TBL *	sb_tbl;
+	int			(*vmt_create)(VIEW_METHOD *,MATRIX_NODE *);
+	void			(*vmt_free)(VIEW_METHOD*);
+	void			(*vmt_draw)(VIEW_METHOD*,GBVIEW_FLAME *,RESOURCE * r,DRAW_WORK *);
+	void			(*vmt_point)(VIEW_METHOD*,GBVIEW_FLAME *,RESOURCE * r,GET_POINT_WORK*);
+} VIEW_METHOD_TBL;
+
 XL_SEXP * gb_gmxCreate();
 XL_SEXP * gb_gmxMatrixParam();
 XL_SEXP * gb_gmxPriority();
@@ -97,5 +124,13 @@ void init_gmxScan(XLISP_ENV * env0,XLISP_ENV * env1);
 void init_gmxStatus(XLISP_ENV * env0,XLISP_ENV * env1);
 void init_gmxCopy(XLISP_ENV * env0,XLISP_ENV * env1);
 
+extern VIEW_METHOD_TBL **vm_tbl[RT_MAX];
+
+VM_WORK_HEADER *
+get_vm_work_header(RESOURCE * r,VIEW_METHOD_TBL * tbl,int size);
+VM_WORK_HEADER *
+_get_vm_work_header(RESOURCE * r,VIEW_METHOD_TBL * tbl,int size);
+
+
 #endif
 
