@@ -207,6 +207,7 @@ typedef struct obj_header {
 #define OF_INFO_NOCHECK	0x00000000
 #define OF_INFO_FETCH	0x00000001
 #define OF_INFO_PROC	0x00000002
+#define OF_INFO_UNSTYLED 0x00000003
 #define OF_ONMAP_REQ	0x00000008
 
 #define OF_INFO_SCHEME	0x000000f0
@@ -369,6 +370,8 @@ typedef struct res_header {
 #define RF_I_ON			0x01000000
 #define RF_I_AUTO		0x02000000
 
+#define RF_REQUIRED_PERMISSION	0x10000000
+
 #define RF_PARAM_FLAGS		(RF_UNCACHE|RF_CACHE_CLEAR|RF_FORCE_LOAD_CHI|RF_INHERIT|RF_EDIT)
 	unsigned int	modify;
 	GB_RECT		minrect;
@@ -397,10 +400,15 @@ typedef struct res_header {
 	int		cache_file_id;
 
 	int		draw_code;
+	
+	int		loop_no;
 #ifdef USE_MATRIX
 	MATRIX *	mtx;
 	unsigned	mtx_loading:1;
-	int		visu_channel;
+	struct vm_work_header *	vm_wk;
+	struct view_method *	vm;
+	int		non_setup_vm;
+//	int		visu_channel;
 #endif
 } RES_HEADER;
 
@@ -423,7 +431,7 @@ typedef struct pixel_map_r64 {
 	int		max_level;
 	TREE_CACHE	tc;
 	int		exit_lock;
-	int		loop_no;
+//	int		loop_no;
 } PIXEL_MAP_R64;
 
 typedef struct coordinate {
@@ -569,7 +577,7 @@ typedef struct draw_gb {
 	DRAW_MATRIX *	dm;
 
 	GB_POINT *	pitch_list;
-	int		loop_no;
+//	int		loop_no;
 	SYS_QUEUE	ir_que;
 	INFO_SCHEME *	ischeme;
 	REAL1		onmap_indicate_size;
@@ -883,6 +891,7 @@ typedef struct load_resource_work {
 	RESOURCE_TYPE_LIST * rt;
 	XL_SEXP *	_meta_ret;
 	char		_data_flag;
+	/* 0 == metadata only , 1 = with small data , 2 = with large data */
 	char *		_mode;
 
 	unsigned int	insert_time;
@@ -892,6 +901,7 @@ typedef struct load_resource_work {
 
 	struct load_resource_work *	first_next;
 
+	L_CHAR *			url_str;
 	struct load_resource_work *	same_list;
 	struct load_resource_work *	same_next;
 
