@@ -251,6 +251,24 @@ typedef struct s_OSSL{
 
 #include	"machine/stream.h"
 
+#define S_PRINTF_OUTPUT_BUF_LEN		1024
+
+typedef struct s_printf_sat {
+#define SPSAT_MEM	0
+#define SPSAT_TEMP	1
+#define SPSAT_RET	2
+#define SPSAT_MAX	3
+	char *			alc[SPSAT_MAX];
+	int			alc_len[SPSAT_MAX];
+	int			alc_size[SPSAT_MAX];
+	L_CHAR *		str_buf;
+	int			str_buf_ptr;
+	STREAM *		st;
+} S_PRINTF_SAT;
+
+
+
+
 extern S_FILE __s_std[3];
 
 /*
@@ -299,7 +317,7 @@ int s_read(STREAM *,void *,int);
 int s_printf(STREAM *,char *,...);
 int s_flush(STREAM *);
 int s_push(STREAM *,char);
-int _s_printf(STREAM*,int*,char*,va_list);
+int _s_printf(STREAM*,int*,char*,va_list,S_PRINTF_SAT * );
 int ss_printf(char *,...);
 int ss_sprintf(L_CHAR *,char*,...);
 int e_printf(STREAM*,int*,char *,...);
@@ -374,6 +392,15 @@ calc_checksum(STREAM * s,void * data,int len,int fags);
 void
 s_shutdown_stream(int flags);
 
+
+void
+new_spsat(S_PRINTF_SAT * sat,STREAM * st);
+void
+finish_spsat(S_PRINTF_SAT * sat,int * erp);
+int
+flush_spsat(S_PRINTF_SAT * sat,int * erp);
+
+
 extern int shutdown_stream_flags;
 
 
