@@ -33,7 +33,10 @@ extern "C" {
 #define VCT_SAVE_FILE		2
 
 char *	v_choose_file(const L_CHAR *title = 0, const char *default_path = 0);
+char *	v_save_as_file(const L_CHAR *title = 0, const char *default_path = 0);
+
 void init_VChooseFile(XLISP_ENV *env);
+void init_VSaveAsFile(XLISP_ENV *env);
 
 #ifdef __cplusplus
 }
