@@ -166,9 +166,7 @@ VObject * v;
 				arg->h.line,
 				XLE_PROTO_INV_OBJECT,
 				l_string(std_cm,objectname),
-				List(n_get_string("invalid referenced object (refer) obj_type ="),
-					get_integer(v->get_type(),0),
-					-1));
+				List(n_get_string("invalid referenced object (refer) obj_type"),					-1));
 		}
 		ex_er = obj->set_status(sts_ptr,flags);
 		if ( ex_er.code != V_ER_NO_ERR )
