@@ -580,6 +580,7 @@ g_ptr64(int * errp,FAVT64_ROOT * rt,FAVT64_PTR * ptr)
 			return 0;
 		((FAVT64_NODE *)(ptr->ptr))->parent = ptr;
 	}
+	touch_ring64(ptr->ptr,0);
 	return ptr->ptr;
 }
 
@@ -711,6 +712,7 @@ favt64_insert(int * errp,
 {
 FAVT64_NODE * ret;
 FAVT64_NODE * g;
+	touch_ring64(p,0);
 	if ( favtp->fofs == 0 ) {
 		if ( a->data == 0 )
 			er_panic("avt_insert(1)");
@@ -973,14 +975,20 @@ _favt64_delete_small(int * errp,FAVT64_ROOT *p,FAVT64_PTR * ap)
 FAVT64_NODE * ret;
 FAVT64_NODE * g;
 	g = g_ptr64(errp,p,ap);
+	favt64_lock(&g->h);
 	if ( g->small.fofs ) {
 		ret = _favt64_delete_small(errp,p,&g->small);
 		fset_level64(errp,p,g);
+		favt64_unlock(&g->h);
 		return ret;
 	}
 	ret = g;
 	set_favt64_ptr(ap,g->large);
 	favt64_valance(errp,p,ap);
+
+	touch_ring64(0,ret);
+
+	favt64_unlock(&ret->h);
 	return ret;
 }
 
@@ -1275,15 +1283,11 @@ FAVT64_NODE * n1;
 void
 check_cache64(char * str)
 {
-FAVT64_HEADER * h;
-int cnt;
+FAVT64_HEADER * h,*h2;
 	if ( favt64_h.next == 0 )
 		return;
-	cnt = 200;
 	for ( h = favt64_h.next ; h != &favt64_h ;
-			h = h->next , cnt -- ) {
-		if ( cnt < 0 )
-			er_panic("chec_cache(2)");
+			h = h->next  ) {
 		if ( h->type == PNT_FAVT_ROOT )
 			cc_root64(str,(FAVT64_ROOT*)h);
 		if ( h->type != PNT_FAVT_ROOT && 
@@ -1291,5 +1295,7 @@ int cnt;
 			er_panic("check_cache(3)");
 		if ( h->next == 0 )
 			er_panic("check_cache(1)");
+		h2 = h->next->prev;
+		h2 = h->prev->next;
 	}
 }
