@@ -325,8 +325,8 @@ fs_raw_write64(PDB64 * p,void * d,int flags)
 PN64_HEADER * h;
 PN64_HEADER hh;
 U_INTEGER64 size;
-#define DUMMY_SIZE 100
-char dummy[DUMMY_SIZE];
+#define DUMMY_SIZE 60000
+char * dummy;
 int s;
 int er,len;
 U_INTEGER64 offset,last_offset;
@@ -350,6 +350,7 @@ int pflags;
 		fa_write64_header(p,d,sizeof(*h));
 		pflags = p->flags & PF_DEBUG;
 		p->flags &= ~PF_DEBUG;
+		dummy = d_alloc(DUMMY_SIZE);
 		for ( s = size - sizeof(*h) ; s > 0 ; ) {
 			if ( s > DUMMY_SIZE )
 				len = DUMMY_SIZE;
@@ -359,6 +360,7 @@ int pflags;
 		}
 		p->flags |= pflags;
 		last_offset = u_lseek64(p->fid,0,SEEK_CUR);
+		d_f_ree(dummy);
 
 		debug_pdb64_list(p,DT_BOUNDARY,offset,last_offset - offset);
 		
@@ -491,7 +493,7 @@ length,fofs);
 		if ( size > 0x10000 )
 			_s = 0x10000;
 		else	_s = size;
-		er = u_read(p->fid,h+1,_s);
+		er = u_read(p->fid,ptr,_s);
 		if ( er < _s )
 			return 0;
 		ptr += er;
@@ -510,7 +512,7 @@ open_filespace64(char * filename,int oflags,int mode,
 {
 PDB64 * p;
 INTEGER64 length;
-PN64_FILE_HEADER h;
+PN64_FILE_HEADER h,*fh;
 PN64_FREELIST	f, * ff;
 FREELIST64 * fp;
 U_INTEGER64 fofs;
@@ -521,7 +523,6 @@ U_INTEGER64 fofs;
 	p->pdb64_debug_root = 0;
 //p->flags |= PF_DEBUG;
 	debug_pdb64_list(p,DT_INSERT,0,0);
-		
 	length = u_lseek64(p->fid,0,SEEK_END);
 	if ( length == 0 ) {
 		h.h.size = sizeof(h);
@@ -532,7 +533,9 @@ U_INTEGER64 fofs;
 			strcpy(h.encoding,"UTF-8");
 		else	strcpy(h.encoding,encoding);
 		h.linear = 0;
-		h.linear_length = 0;
+		if ( (oflags & O_RDWR) == O_RDWR )
+			h.flags = FTF_WRITE;
+		else	h.flags = 0;
 		change_endian_file_header64(&h);
 		
 		debug_pdb64_list(p,DT_INSERT,0,sizeof(h));
@@ -552,6 +555,24 @@ U_INTEGER64 fofs;
 		}
 	}
 	else {
+		if ( (oflags & O_RDWR) == O_RDWR ) {
+			fofs = 0;
+			fh = get_file_record64(&fofs,p,-1,0);
+			if ( fh == 0 ) {
+				close_pdb64(p);
+				return 0;
+			}
+			change_endian_file_header64(fh);
+			if ( fh->flags & FTF_WRITE ) {
+				d_f_ree(fh);
+				close_pdb64(p);
+				return 0;
+			}
+			fh->flags |= FTF_WRITE;
+			change_endian_file_header64(fh);
+			write_filespace64f(p,fofs,(void*)fh);
+			d_f_ree(fh);
+		}
 		fofs = 0;
 		ff = get_file_record64(&fofs,p,PNT_FREELIST_HEADER,0);
 		if ( ff ) {
@@ -587,11 +608,26 @@ FREELIST64 * f2;
 void
 close_filespace64(PDB64 * p)
 {
+U_INTEGER64 fofs;
+PN64_FILE_HEADER *fh;
 
 	if ( p->freelist_work )
 		free_freelist64(p->freelist_work);
 	p->freelist_work = 0;
 	flush_favt64_cache(p);
+	if ( (p->oflags & O_RDWR) == O_RDWR ) {
+		fofs = 0;
+		fh = get_file_record64(&fofs,p,-1,0);
+		if ( fh == 0 ) {
+			goto end;
+		}
+		change_endian_file_header64(fh);
+		fh->flags &= ~FTF_WRITE;
+		change_endian_file_header64(fh);
+		write_filespace64f(p,fofs,(void*)fh);
+		d_f_ree(fh);
+	}
+end:
 	debug_pdb64_list(p,DT_ALL_DELETE,0,0);
 	close_pdb64(p);
 }
