@@ -32,8 +32,9 @@
 #define SCRIPT_TRIGGER
 #define SCRIPT_DEBUG
 #define SCRIPT_ERR
-*/
 
+#define SCRIPT_DEBUG_TRIGGER
+*/
 
 #define TIME_DOMAIN	120
 
@@ -56,13 +57,14 @@ SYS_QUEUE matrix_que;
 XLISP_ENV * matrix_xl_env;
 MATRIX_DATA_TYPE * mtx_type_tbl[MDT_MAX];
 int load_indicate_tick_end_flag;
+INTEGER64 matrix_update_time;
 
 void _close_matrix(MATRIX * m);
 
 MATRIX *
 _open_matrix(L_CHAR * neturl,L_CHAR * filename,L_CHAR * key,void (*open_method)(MATRIX_TOKEN*),void * work);
 
-MATRIX_NODE * _get_matrix_node(int * errp,MATRIX * m,INTEGER64 * dim_code,int,INTEGER64,XL_SEXP **);
+MATRIX_NODE * _get_matrix_node(int * errp,MATRIX * m,INTEGER64 * dim_code,int,INTEGER64,XL_SEXP **,int pt_key);
 
 void _wait_matrix_mode(MATRIX * m);
 int _set_matrix_channel_info(MATRIX * m,int ch,MATRIX_CHANNEL_INFO * inf);
@@ -79,7 +81,7 @@ void _delete_node_ring(MATRIX_NODE * n);
 void _get_matrix_access(MATRIX_NODE * n);
 int  _cmp_dim_code(MATRIX * m,INTEGER64 * dim_code1,INTEGER64 * dim_code2);
 INTEGER64 * _copy_dim_code(MATRIX * m,INTEGER64 * dim_code);
-MATRIX_NODE * _get_matrix_tree(int * errp,MATRIX * m,INTEGER64 * dim_code,int access);
+MATRIX_NODE * _get_matrix_tree(int * errp,MATRIX * m,INTEGER64 * dim_code,int access,int pt_key);
 MATRIX_NODE * _get_matrix_tree_1(int * errp,MATRIX * m,INTEGER64 * dim_code,int access);
 MATRIX_NODE * _get_matrix_tree_2(int * errp,MATRIX * m,INTEGER64 * dim_code,int access);
 void matrix_exec_cal(MATRIX_TOKEN * t);
@@ -130,6 +132,8 @@ void _set_matrix_env(MATRIX * m,char * name,char * data);
 int mx_last_access(int *);
 void mx_purge();
 
+void
+init_mxPgPlot(XLISP_ENV * env);
 
 int
 _dc_peano_inc(MATRIX * m,
@@ -173,7 +177,7 @@ init_matrix()
 	matrix_que.gc_func = 0;
 	matrix_que.gc_get = 0;
 	matrix_que.key_func = (void(*)(TKEY))matrix_que_task;
-	matrix_que.pri = PRI_DRAW;
+	matrix_que.pri = PRI_MATRIX_DRAW;
 	setup_queue(&matrix_que);
 
 
@@ -235,6 +239,10 @@ init_matrix()
 	init_sbPrimitive(matrix_xl_env);
 	init_sbHeuristicLayering(matrix_xl_env);
 	
+	init_mxPgPlot(matrix_xl_env);
+	init_mxObjID(matrix_xl_env);
+
+	
 	new_tick((void(*)(int))matrix_access_tick,STAT_TICK,0);
 }
 
@@ -339,6 +347,46 @@ matrix_access_tick()
 	unlock_task(matrix_lock,"matrix_access_tick");
 }
 
+
+int
+_get_matrix_update_time(MATRIX_NODE * n,int ch,int ix)
+{
+INTEGER64 * _ix;
+int ret;
+	ret = 0;
+	_ix = &n->channel[ch].update_time[0];
+	switch ( ix ) {
+	case UT_CMP:
+		if ( _ix[UT_DATA] == _ix[UT_SB] )
+			ret = UT_EQU;
+		else if ( _ix[UT_DATA] < _ix[UT_SB] )
+			ret = UT_SB;
+		else	ret = UT_DATA;
+		break;
+	case UT_EQU:
+		if ( _ix[UT_DATA] < _ix[UT_SB] )
+			_ix[UT_DATA] = _ix[UT_SB];
+		else	_ix[UT_SB] = _ix[UT_DATA];
+		break;
+	default:
+		matrix_update_time ++;
+		_ix[ix] = matrix_update_time;
+		break;
+	}
+	return ret;
+}
+
+int
+get_matrix_update_time(MATRIX_NODE * n,int ch,int ix)
+{
+int ret;
+	lock_task(matrix_lock);
+	ret = _get_matrix_update_time(n,ch,ix);
+	unlock_task(matrix_lock,"get_matrix_update_time");
+	return ret;
+}
+
+
 void 
 insert_matrix_type_table(MATRIX_DATA_TYPE * tp)
 {
@@ -365,6 +413,8 @@ _unlock_save(MATRIX_NODE*n)
 	n->dirty_file_time = 0;
 	wakeup_task((int)n);
 	wakeup_task((int)n->matrix);
+	if ( matrix_que.total_cnt == 0 )
+		wakeup_task((int)_close_matrix);
 }
 
 
@@ -617,6 +667,8 @@ _matrix_node_channel_unlock(MATRIX_NODE * n,int flags)
 	}
 	wakeup_task((int)n->matrix);
 	wakeup_task((int)n);
+	if ( matrix_que.total_cnt == 0 )
+		wakeup_task((int)_close_matrix);
 	
 }
 
@@ -693,6 +745,42 @@ MATRIX * ret;
 	return ret;
 }
 
+MATRIX_SEXP *
+new_matrix_sexp(XL_SEXP* s)
+{
+MATRIX_SEXP * ret;
+	lock_task(matrix_lock);
+	ret = d_alloc(sizeof(*ret));
+	memset(ret,0,sizeof(*ret));
+	ret->data = s;
+	ret->gc_func = gc_gb_sexp;
+	_insert_matrix_sexp(ret);
+	unlock_task(matrix_lock,"new_matrix_sexp");
+	return ret;
+}
+
+INTEGER64
+_get_matrix_obj_id(MATRIX * m)
+{
+INTEGER64 ret;
+	ret = m->obj_id;
+	ret += 256;
+	if ( ret <= 0 )
+		ret = 256;
+	m->obj_id = ret;
+	return ret;
+}
+
+INTEGER64
+get_matrix_obj_id(MATRIX * m)
+{
+INTEGER64 ret;
+	lock_task(matrix_lock);
+	ret = _get_matrix_obj_id(m);
+	unlock_task(matrix_lock,"get_matrix_obj_id");
+	return ret;
+}
+
 
 MATRIX *
 open_matrix_with_search(L_CHAR * neturl,L_CHAR * filename,L_CHAR * key,
@@ -803,6 +891,8 @@ MATRIX_TOKEN * t;
 int ret_id;
 int pri;
 int retry_f;
+void check_pdb_fd(MATRIX*);
+
 	retry_f = 0;
 	if ( m->mode == MM_CLOSE )
 		return;
@@ -811,6 +901,7 @@ int retry_f;
 	m->mode = MM_CLOSE;
 	_delete_matrix_ring(m);
 
+
 retry:
 	_flush_all_dirty_file(m);
 
@@ -862,10 +953,10 @@ ss_printf("close_matirx ret_id = %i %i\n",ret_id,matrix_que.total_cnt);
 		retry_f = 1;
 	}
 	if ( retry_f ) {
-		new_timeout((int)m,1);
+		new_timeout((int)_close_matrix,1);
 		pri = get_pri(0);
 		change_pri(0,PRI_RCACHE);
-		sleep_task((int)m,matrix_lock);
+		sleep_task((int)_close_matrix,matrix_lock);
 		change_pri(0,pri);
 		lock_task(matrix_lock);
 		del_timeout((int)m);
@@ -1029,7 +1120,7 @@ int max;
 			lev = 0;
 			for ( ; pix > 1 ; ) {
 				lev ++;
-				if ( pix & ((1<<m->dim_divide[i])-1) )
+				if ( pix & ((((INTEGER64)1)<<m->dim_divide[i])-1) )
 					pix = (pix >> m->dim_divide[i]) + 1;
 				else	pix = pix >> m->dim_divide[i];
 			}
@@ -1061,7 +1152,7 @@ int max;
 	for ( i = 1 ; i < m->total_levels ; i ++ ) {
 		for ( j = 0 ; j < m->p.dim ; j ++ ) {
 			pix = m->pixel_size_list[i-1][j];
-			if ( pix & ((1<<m->dim_divide[j])-1) )
+			if ( pix & ((((INTEGER64)1)<<m->dim_divide[j])-1) )
 				pix = (pix >> m->dim_divide[j]) + 1;
 			else 	pix = (pix >> m->dim_divide[j]);
 			if ( pix == 0 )
@@ -1300,6 +1391,8 @@ MATRIX_TOKEN * t;
 		_insert_matrix_access(t,matrix_exec_cal);
 	}
 	wakeup_task((int)m);
+	if ( matrix_que.total_cnt == 0 )
+		wakeup_task((int)_close_matrix);
 }
 
 void
@@ -1650,8 +1743,6 @@ int i;
 #endif
 
 
-check_point(t);
-
 	e = t->env->data;
 	m = t->process_node->matrix;
 
@@ -1713,6 +1804,14 @@ see_access_list(t->access_list);
 		if ( get_type(t->cal_target) == XLT_NULL )
 			goto success;
 	}
+/*
+	if ( t->process_node->matrix->p.trigger ) {
+		if ( (*t->process_node->matrix->p.trigger)(TRT_CANCEL,t) < 0 ) {
+			_matrix_token_error(t);
+			goto end1;
+		}
+	}
+*/
 	unlock_task(matrix_lock,"matrix_exec_cal");
 	for( ; get_type(t->cal_target) == XLT_PAIR ; ) {
 		lock_task(matrix_lock);
@@ -1805,6 +1904,8 @@ see_access_list(t->access_list);
 				_insert_matrix_access(t2,matrix_exec_cal);
 			}
 			wakeup_task((int)n);
+			if ( matrix_que.total_cnt == 0 )
+				wakeup_task((int)_close_matrix);
 		}
 		if ( t->err_jump >= 0 ) {
 
@@ -1850,7 +1951,12 @@ see_access_list(t->access_list);
 	if ( t->normal_jump_status >= 0 ) {
 		t->process_node->status = t->normal_jump_status;
 		if ( t->process_node->status == MS_OK && t->process_node->matrix->p.trigger )
+{
+#ifdef SCRIPT_DEBUG_TRIGGER
+ss_printf("TRIGGER %p :: %s\n",t,pt_dc(t->process_node->matrix,t->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			(*t->process_node->matrix->p.trigger)(TRT_TOKEN,t);
+}
 		_matrix_send_result(t);
 		n = t->process_node;
 		for ( ; n->wait_token ; ) {
@@ -1860,6 +1966,8 @@ see_access_list(t->access_list);
 			_insert_matrix_access(t2,matrix_exec_cal);
 		}
 		wakeup_task((int)t->process_node);
+		if ( matrix_que.total_cnt == 0 )
+			wakeup_task((int)_close_matrix);
 	}
 	t->cal_target = 0;
 	if ( t->access_list ) {
@@ -1882,6 +1990,8 @@ ss_printf("EXIT %x:%i =\n",t,t->access_target_id);
 	n = t->process_node;
 	n->process_token = 0;
 	wakeup_task((int)n);
+	if ( matrix_que.total_cnt == 0 )
+		wakeup_task((int)_close_matrix);
 	if ( t->aboat_status > 0 )
 		t->aboat_status = -t->aboat_status;
 	if ( t->aboat_status == 0 ) {
@@ -1897,6 +2007,8 @@ ss_printf("EXIT %x:%i =\n",t,t->access_target_id);
 		_insert_matrix_access(t,matrix_exec_cal);
 	}
 	wakeup_task((int)n);
+	if ( matrix_que.total_cnt == 0 )
+		wakeup_task((int)_close_matrix);
 end1:
 	unlock_task(matrix_lock,"matrix_exec_cal");
 	if ( m->token_cnt == 0 && m->p.trigger )
@@ -1914,6 +2026,8 @@ ss_printf("MATRIX_TOKEN_ERR %p NODE=%p %i (ERR_JUMP_STATUS)\n",t,t->process_node
 #endif
 		t->process_node->status = t->err_jump_status;
 		wakeup_task((int)t->process_node);
+		if ( matrix_que.total_cnt == 0 )
+			wakeup_task((int)_close_matrix);
 		_matrix_send_result(t);
 	}
 	if ( t->err_jump >= 0 ) {
@@ -1985,6 +2099,8 @@ MATRIX_LIST ** lp,* lst;
 	}
 	wakeup_task((int)n->matrix);
 	wakeup_task((int)n);
+	if ( matrix_que.total_cnt == 0 )
+		wakeup_task((int)_close_matrix);
 }
 
 void
@@ -2111,6 +2227,8 @@ ss_printf("MTR2 %x:%i = %i\n",t,-1,MI_FETCH_1_TP);
 		if ( clear_err ) {
 			n->status = MS_OK;
 			wakeup_task((int)n);
+			if ( matrix_que.total_cnt == 0 )
+				wakeup_task((int)_close_matrix);
 		}
 		if ( _access != MI_FETCH_1_TP )
 {
@@ -2123,6 +2241,8 @@ ss_printf("MTR3 %x:%i = %i\n",t,-1,MI_EDIT_1_TP);
 	case MS_EDIT_ERR_2:
 		if ( clear_err ) {
 			n->status = MS_OK;
+			if ( matrix_que.total_cnt == 0 )
+				wakeup_task((int)_close_matrix);
 			wakeup_task((int)n);
 		}
 		if ( _access != MI_FETCH_1_TP )
@@ -2292,7 +2412,7 @@ XL_SEXP * ret;
 }
 
 MATRIX_NODE *
-_get_matrix_node(int * errp,MATRIX * m,INTEGER64 * dim_code,int access,INTEGER64 lev,XL_SEXP ** retp)
+_get_matrix_node(int * errp,MATRIX * m,INTEGER64 * dim_code,int access,INTEGER64 lev,XL_SEXP ** retp,int pt_key)
 {
 MATRIX_NODE * n;
 unsigned int key;
@@ -2326,6 +2446,7 @@ unsigned int key;
 	if ( n ) {
 		_delete_node_ring(n);
 		_insert_node_ring(n);
+		n->process_token_key = pt_key;
 		n->req_level = lev;
 		switch ( n->status ) {
 		case MS_NOBIND:
@@ -2345,6 +2466,8 @@ unsigned int key;
 			}
 			n->status = MS_NOBIND;
 			wakeup_task((int)n);
+			if ( matrix_que.total_cnt == 0 )
+				wakeup_task((int)_close_matrix);
 			_get_matrix_access(n);
 			if ( errp )
 				*errp = ME_NO_NODE;
@@ -2358,7 +2481,6 @@ unsigned int key;
 			}
 			n->status = MS_PROCESS;
 			wakeup_task((int)n);
-ss_printf("VISU trigger %p\n",n);
 			_matrix_trigger_access(n,MI_VISU_1_TP,0);
 			if ( errp )
 				*errp = ME_NO_NODE;
@@ -2400,6 +2522,7 @@ ss_printf("VISU trigger %p\n",n);
 				m->dim_bit_field);
 		n->nlist_dim_bit_field_len = m->dim_bit_field;
 	}
+	n->process_token_key = pt_key;
 	set_send_data(n,retp);
 	m->node_hash[key] = n;
 	_insert_node_ring(n);
@@ -2418,7 +2541,7 @@ MATRIX_NODE * n;
 int err;
 	lock_task(matrix_lock);
 	err = 0;
-	n = _get_matrix_node(&err,m,dim_code,access,dim_code[0],retp);
+	n = _get_matrix_node(&err,m,dim_code,access,dim_code[0],retp,0);
 	if ( errp && err )
 		*errp = err;
 	if ( err ) {
@@ -2446,7 +2569,7 @@ int err;
 retry:
 	lock_task(matrix_lock);
 	err = 0;
-	n = _get_matrix_node(&err,m,dim_code,access,dim_code[0],0);
+	n = _get_matrix_node(&err,m,dim_code,access,dim_code[0],0,0);
 	if ( n && n->status <= MS_PROCESS ) {
 
 #ifdef SCRIPT_DEBUG
@@ -2499,6 +2622,34 @@ INTEGER64 d;
 	return ret;
 }
 
+int
+_check_children(MATRIX_NODE * n)
+{
+int i;
+	if ( n->dim_code[0] == 0 )
+		return 0;
+	if ( n->matrix->dim_bit_field ) {
+		for ( i = 0 ; i < n->matrix->dim_bit_field ; i ++ )
+			if ( n->nlist_dim_bit_field[i] )
+				return 1;
+		return 0;
+	}
+	else {
+		if ( n->nlist_dim_addr_len )
+			return 1;
+		return 0;
+	}
+}
+
+int
+check_children(MATRIX_NODE * n)
+{
+int ret;
+	lock_task(matrix_lock);
+	ret = _check_children(n);
+	unlock_task(matrix_lock,"insert_dim_code_index");
+	return ret;
+}
 
 int
 _check_dim_code(MATRIX_NODE * n,INTEGER64 * dim_code)
@@ -2555,7 +2706,7 @@ int i;
 		return;
 	max_ix = 1;
 	for ( i = 0 ; i < n->matrix->p.dim ; i ++ )
-		max_ix *= (1<<n->matrix->dim_divide[i]);
+		max_ix *= (((int)1)<<n->matrix->dim_divide[i]);
 	for ( ix = 0 ; ix < max_ix ; ix ++ )
 		n->nlist_dim_bit_field[ix/8] |= (1<<(ix % 8));
 	if ( dirty )
@@ -2646,28 +2797,62 @@ insert_dim_code_index(MATRIX_NODE * n,INTEGER64 * dim_code,int dirty)
 	unlock_task(matrix_lock,"insert_dim_code_index");
 }
 
+int
+power_of(U_INTEGER64 a,int n)
+{
+
+	if ( a == 0 )
+		return -1;
+	for ( ; a % n == 0  ; a = a / n );
+	if ( a == 1 )
+		return 0;
+	return -1;
+}
+
 MATRIX_NODE *
-_get_matrix_tree(int * errp,MATRIX * m,INTEGER64 * dim_code,int access)
+_get_matrix_tree(int * errp,MATRIX * m,INTEGER64 * dim_code,int access,int pt_key)
 {
 MATRIX_NODE * ret,* _ret,*prev;
 int err;
-INTEGER64 lev;
+INTEGER64 lev,target;
+int er_f;
 	lev = dim_code[0];
-	dim_code[0] = m->total_levels-1;
-	err = 0;
+	ret = 0;
+	if ( access == GN_STEP_NODE_CREATE ) {
+		dim_code[0] = m->total_levels-1;
+		target = m->total_levels-1;
+		for ( ; dim_code[0] >= lev ; dim_code[0] -- ) {
+			err = 0;
+			_ret = _get_matrix_node(&err,m,dim_code,GN_READ_ONLY,lev,0,pt_key);
+			if ( err == ME_MATRIX_ERR )
+				goto end;
+			if ( err == 0 )
+				target = dim_code[0];
+		}
+		dim_code[0] = target;
+	}
+	else {
+		dim_code[0] = m->total_levels-1;
+		err = 0;
+		_ret = _get_matrix_node(&err,m,dim_code,GN_READ_ONLY,lev,0,pt_key);
+		if ( err ) {
+			if ( err == ME_MATRIX_ERR )
+				goto end;
+			if ( access == GN_READ_ONLY )
+				goto end;
+		}
+	}
 	ret = 0;
 	prev = 0;
-	_ret = _get_matrix_node(&err,m,dim_code,GN_READ_ONLY,lev,0);
-	if ( err ) {
-		if ( err == ME_MATRIX_ERR )
-			goto end;
-		if ( access == GN_READ_ONLY )
-			goto end;
-	}
 	_ret = 0;
+	er_f = 0;
 	for ( ; dim_code[0] >= lev ; dim_code[0] -- , prev = _ret ) {
 		err = 0;
-		_ret = _get_matrix_node(&err,m,dim_code,access,lev,0);
+		if ( access != GN_STEP_NODE_CREATE )
+			_ret = _get_matrix_node(&err,m,dim_code,access,lev,0,pt_key);
+		else if ( (dim_code[0] == lev) || (power_of(dim_code[0] - lev + 1,2) == 0) )
+			_ret = _get_matrix_node(&err,m,dim_code,GN_NODE_CREATE,lev,0,pt_key);
+		else	_ret = _get_matrix_node(&err,m,dim_code,GN_READ_ONLY,lev,0,pt_key);
 		if ( err == 0 ) {
 			ret = _ret;
 			switch ( access ) {
@@ -2685,10 +2870,17 @@ INTEGER64 lev;
 			case GN_READ_ONLY:
 				break;
 			case GN_NODE_CREATE:
-				if ( prev == 0 )
+			case GN_STEP_NODE_CREATE:
+				if ( prev == 0 ) {
+					er_f = 1;
 					continue;
-				if ( _check_dim_code(prev,dim_code) )
-					continue;	
+				}
+				if ( er_f )
+					continue;
+				if ( _check_dim_code(prev,dim_code) ) {
+					er_f = 1;
+					continue;
+				}
 				break;
 			case GN_LIST_CREATE:
 				if ( prev == 0 )
@@ -2708,12 +2900,21 @@ end:
 	return ret;
 }
 
+MATRIX_NODE *
+get_matrix_tree(int * errp,MATRIX * m,INTEGER64 * dim_code,int access,int pt_key)
+{
+MATRIX_NODE * ret;
+	lock_task(matrix_lock);
+	ret = _get_matrix_tree(errp,m,dim_code,access,pt_key);
+	unlock_task(matrix_lock,"get_matrix_tree");
+	return ret;
+}
 
 void *
 get_matrix_node_channel(int * errp,MATRIX_NODE ** np,
 		MATRIX * m,INTEGER64 * dim_code,
 		int ch,int type,int access,
-		MATRIX_ALLOC_VECTOR_PARAM * vp)
+		MATRIX_ALLOC_VECTOR_PARAM * vp,int pt_key)
 {
 MATRIX_NODE * n;
 int err;
@@ -2729,7 +2930,7 @@ retry:
 	if ( type == GN_TREE ) {
 		ret = 0;
 		err = 0;
-		n = _get_matrix_tree(&err,m,dim_code,access);
+		n = _get_matrix_tree(&err,m,dim_code,access,pt_key);
 		if ( err == ME_MATRIX_ERR ) {
 			if ( errp )
 				*errp = err;
@@ -2742,7 +2943,7 @@ retry:
 		goto end;	
 	}
 	err = 0;
-	n = _get_matrix_node(&err,m,dim_code,access,dim_code[0],0);
+	n = _get_matrix_node(&err,m,dim_code,access,dim_code[0],0,pt_key);
 	if ( err == ME_MATRIX_ERR ) {
 		if ( errp )
 			*errp = err;
@@ -2932,6 +3133,10 @@ char * err_msg;
 		goto no_obj;
 	}
 	md = m->channel_info[ch].data_type;
+	if ( md == 0 ) {
+		err_msg = "no data channel";
+		goto no_obj;
+	}
 	if ( md->type == MDT_SEXP ) {
 		_matrix_node_channel_lock(n);
 		sx = n->channel[ch].data;
@@ -3132,6 +3337,7 @@ MATRIX_SEXP * s1, * s2;
 			if ( cf )
 				(*md->free_data)(md,h);
 		}
+		 _get_matrix_update_time(n,ch,UT_DATA);
 		if ( m->channel_info[ch].flags & MF_FILE )
 			_set_dirty_file(n);
 		_matrix_node_channel_unlock(n,0);
@@ -3314,7 +3520,7 @@ dc_end[0],dc_end[1],dc_end[2]);
 		}
 		err = 0;
 		n = _get_matrix_node(&err,m,dc,GN_ERROR_NORETRY,
-					dc_start[0],0);
+					dc_start[0],0,0);
 		if ( n )
 			_matrix_trigger_access(n,_access,0);
 		_unlock_node(n,0);
@@ -3785,7 +3991,7 @@ MATRIX_NODE * n;
 		if ( err < 0 )
 			return err;
 		mst->channel_data = get_matrix_node_channel(&err,&n,w->m,dim_code,mst->channel,
-					mst->gn_tree_node,mst->gn_create,0);
+					mst->gn_tree_node,mst->gn_create,0,0);
 		unlock_node(n,0);
 		mst->n = n;
 		if ( err < 0 )
@@ -4316,4 +4522,15 @@ end:
 	return ret;
 }
 
+void
+block_check_sum(char * msg,MATRIX_ALLOC_BLOCK_PARAM * p)
+{
+int sum = 0;
+unsigned char * ptr;
+int s;
+	s = p->size ;
+	for ( ptr = (unsigned char*)p->block ; s > 0 ; s -- , ptr ++ )
+		sum += *ptr;
+	ss_printf("CHK %s %i - %i\n",msg,sum,p->size);
+}
 
