@@ -160,7 +160,7 @@ int ef;
 		get_matrix_node_channel
 			(&err,&n,c->m,
 			src,c->access_ch[0],
-			c->gn_tree_node,c->gn_create,0);
+			c->gn_tree_node,c->gn_create,0,0);
 		if ( n && err >= 0 ) {
 			matrix_node_channel_unlock(n,0);
 			unlock_node(n,0);
@@ -184,7 +184,7 @@ int ef;
 		for ( i = 0 ; i < c->ds_len ; i ++ ) {
 			d = get_matrix_node_channel
 				(&err,&n,c->m,src,c->access_ch[i],
-				GN_NODE,GN_NODE_CREATE,0);
+				GN_NODE,GN_NODE_CREATE,0,0);
 			c->ds[i].tp = tp = c->m->channel_info
 					[c->access_ch[i]].data_type;
 			if ( c->ds[i].tp->parent ) {
@@ -600,7 +600,7 @@ int err_flag;
 		plen = -1;
 
 		if ( err_flag ) {
-			slen = 1<<m->block_size[0];
+			slen = ((int)1)<<m->block_size[0];
 			if ( slen > len )
 				slen = len;
 			plen = slen;
