@@ -159,6 +159,17 @@ mx_file_gc_tick()
 }
 
 
+void
+check_pdb_fd(MATRIX * m)
+{
+MX_FILE_WORK * w;
+w = m->file_work;
+if ( w )
+ss_printf("CLOSE POINT = %p\n",w->pdb_fd);
+else
+ss_printf("CLOSE POINT = ZERO W\n");
+}
+
 
 int
 _xx_start_file_access(MATRIX * m,int f,char * __f,int __l)
@@ -192,17 +203,19 @@ int tid;
 		w->lock_d = call_lock(m->filename,CLT_WRITE_LOCK,mx_file_lock_event,m);
 
 
-ss_printf("_start_file_access %ls\n",m->filename);
+ss_printf("_start_file_access %ls %p\n",m->filename,m);
 
 	encoding = l_string(std_cm,"utf8");
 	w->pdb_fd = open_filespace64(
 		n_string(std_cm,m->filename),
 		w->oflags,0644,
 		PF_USEFREELIST,FT_MATRIX,encoding);
+	if ( w->oflags & O_TRUNC )
+		w->oflags &= ~O_TRUNC;
 	if ( w->pdb_fd == 0 ) {
 		call_unlock(w->lock_d);
 		_finish_file_access(m,0);
-ss_printf("A\n");
+ss_printf("A %ls\n",m->filename);
 		return ME_CANNOT_OPEN_FILE;
 	}
 check_pdb64(w->pdb_fd);
@@ -620,7 +633,6 @@ MATRIX_DATA_TYPE * tp;
 	h = rl->data;
 
 	w->header_fofs = alloc_filespace64(w->pdb_fd,rl->data);
-ss_printf("H-1 " I64_FORMAT "\n",h->h.size);
 
 	for ( i = 0 ; i < m->p.channel_nos ; i ++ ) {
 		ci = &m->channel_info[i];
@@ -659,7 +671,6 @@ ss_printf("H-1 " I64_FORMAT "\n",h->h.size);
 
 	setup_recordlist64(rl);
 	h = rl->data;
-ss_printf("H-LAST " I64_FORMAT "\n",h->h.size);
 	change_endian_header64(&h->h);
 	change_endian(h->channel_nos);
 	change_endian(h->dim);
