@@ -266,7 +266,7 @@ int _p;
 	src_inc = d_alloc(sizeof(int)*dim);
 	memcpy(src_ix,rep,sizeof(int)*dim);
 	for ( i = 0 ; i < dim ; i ++ ) {
-		src_inc[i] = 1<<(m->dim_divide[i]*parent);
+		src_inc[i] = ((int)1)<<(m->dim_divide[i]*parent);
 	}
 	for ( ; ; ) {
 		for (  i = 0 ; i < dim ; i ++ )
@@ -333,7 +333,7 @@ int _p;
 	n_size = 1;
 	for ( i = 0 ; i < dim ; i ++ ) {
 		src_ix[i] = 0;
-		src_inc[i] = 1<<(m->dim_divide[i]*parent);
+		src_inc[i] = ((int)1)<<(m->dim_divide[i]*parent);
 		n_size *= src_inc[i];
 		dest_inc[i] = 1;
 		dest_ix[i] = ofs[i];
@@ -406,7 +406,7 @@ char hd_type;
 			_ofs = 1<<(m->block_size[i] - _p);
 			ofs[i] = _ofs * ((dim_code[i+1] >> 
 					(lev * m->dim_divide[i] + m->block_size[i]))
-				& ((1<<m->dim_divide[i]*parent)-1));
+				& ((1<<(m->dim_divide[i]*parent))-1));
 		}
 	}
 	dim = m->p.dim;
@@ -492,7 +492,7 @@ char hd_type;
 			_ofs = 1<<(m->block_size[i] - _p);
 			ofs[i] = _ofs * ((dim_code[i+1] >> 
 					(lev * m->dim_divide[i] + m->block_size[i]))
-				& ((1<<m->dim_divide[i]*parent)-1));
+				& ((1<<(m->dim_divide[i]*parent))-1));
 		}
 	}
 	dim = m->p.dim;
