@@ -364,7 +364,7 @@ char hd_type;
 			_ofs = 1<<(m->block_size[i] - _p);
 			ofs[i] = _ofs * ((dim_code[i+1] >> 
 					(lev * m->dim_divide[i] + m->block_size[i]))
-				& ((1<<m->dim_divide[i]*parent)-1));
+				& ((1<<(m->dim_divide[i]*parent))-1));
 		}
 	}
 	dim = m->p.dim;
@@ -450,7 +450,7 @@ char hd_type;
 			_ofs = 1<<(m->block_size[i] - _p);
 			ofs[i] = _ofs * ((dim_code[i+1] >> 
 					(lev * m->dim_divide[i] + m->block_size[i]))
-				& ((1<<m->dim_divide[i]*parent)-1));
+				& ((1<<(m->dim_divide[i]*parent))-1));
 		}
 	}
 	dim = m->p.dim;
