@@ -50,6 +50,7 @@ mxt_print_uint8(MATRIX_DATA_TYPE*tp,MATRIX_STRING_BUFFER*b,void*d,char*fmt);
 
 MATRIX_DATA_TYPE mx_type_uint8 = {
 	MDT_UINT8,
+	"uint8",
 	0,
 	mxt_uint8_get_size,
 	mxt_uint8_sexp2md,
@@ -75,6 +76,7 @@ MATRIX_DATA_TYPE mx_type_uint8 = {
 
 MATRIX_DATA_TYPE mx_type_uint8_v = {
 	MDT_UINT8|MDT_VECTOR,
+	"uint8_v",
 	&mx_type_uint8,
 	mxt_vector_get_size,
 	mxt_vector_sexp2md,
@@ -406,7 +408,7 @@ int _opt;
 			_ofs = 1<<(m->block_size[i] - _p);
 			ofs[i] = _ofs * ((dim_code[i+1] >> 
 					(lev * m->dim_divide[i] + m->block_size[i]))
-				& ((1<<m->dim_divide[i]*parent)-1));
+				& ((1<<(m->dim_divide[i]*parent))-1));
 		}
 	}
 	dim = m->p.dim;
@@ -504,7 +506,7 @@ int * _opt;
 			_ofs = 1<<(m->block_size[i] - _p);
 			ofs[i] = _ofs * ((dim_code[i+1] >> 
 					(lev * m->dim_divide[i] + m->block_size[i]))
-				& ((1<<m->dim_divide[i]*parent)-1));
+				& ((1<<(m->dim_divide[i]*parent))-1));
 		}
 	}
 	dim = m->p.dim;
