@@ -17,7 +17,9 @@
 
 
 #define SEQUENCE_RESOLVE	1
-
+/*
+#define RESOLVE_DEBUG
+*/
 
 #include	<stdio.h>
 #include	"task.h"
@@ -38,6 +40,7 @@ typedef struct resolve_queue {
 #define RQ_OK_			4
 	unsigned int		start_time;
 	unsigned int		req_time;
+	unsigned		abort_flag:1;
 } RESOLVE_QUEUE;
 
 typedef struct resolve_queue_header {
@@ -162,11 +165,17 @@ retry:
 				return;
 			if ( rq2->pri == 1 &&
 					get_xltime() - rq2->start_time > RESOLV_QUE_TIMEOUT ) {
+#ifdef RESOLVE_DEBUG
+ss_printf("RQ_TIMEOUT-1 %i\n",get_tid());
+#endif
 				rq2->status = RQ_TIMEOUT;
 				wakeup_task((int)rq2);
 				return;
 			}
 			resolve_run = rq2;
+#ifdef RESOLVE_DEBUG
+ss_printf("RQ_RUN-2 %i %p\n",get_tid(),rq2);
+#endif
 			rq2->status = RQ_RUN;
 			wakeup_task((int)rq2);
 			if ( rq2->pri == 0 ) {
@@ -185,8 +194,12 @@ retry:
 		rq2 = resolve_run;
 		resolve_run = 0;
 		rq2->status = RQ_IDLE;
+#ifdef RESOLVE_DEBUG
+ss_printf("RQ_IDLE-3 %i\n",get_tid());
+#endif
 		_insert_resolve_queue(rq2);
 		aboat_resolve_flag = 1;
+		rq2->abort_flag = 1;
 		aboat_resolve_request();
 		new_tick((void(*)(int))wakeup_resolve_thread,-1,0);
 		goto retry;
@@ -215,30 +228,64 @@ _entry_resolve_call(RESOLVE_QUEUE * rq)
 {
 	rq->pri = 0;
 	rq->status = RQ_IDLE;
+	rq->abort_flag = 0;
+#ifdef RESOLVE_DEBUG
+ss_printf("entry-rs RQ_IDLE-4 %i -- %p\n",get_tid(),rq);
+#endif
 	rq->start_time = get_xltime();
 	_insert_resolve_queue(rq);
 	_wakeup_resolve_thread();
 	for ( ; rq->status != RQ_RUN ; ) {
+		_wakeup_resolve_thread();
 		sleep_task((int)rq,resolve_lock2);
 		lock_task(resolve_lock2);
 	}
+#ifdef RESOLVE_DEBUG
+ss_printf("entry-rs END %i\n",get_tid());
+#endif
 	return 0;
 }
 
 int
 _exit_resolve_call(RESOLVE_QUEUE * rq)
 {
+#ifdef RESOLVE_DEBUG
+ss_printf("exit-rs %i - status %i\n",get_tid(),rq->status);
+#endif
 	if ( rq->status == RQ_RUN ) {
 		rq->status = RQ_OK_;
+#ifdef RESOLVE_DEBUG
+ss_printf("RQ_OK_-5 %i\n",get_tid());
+#endif
 		_wakeup_resolve_thread();
+#ifdef RESOLVE_DEBUG
+ss_printf("exit-rs END2 %i\n",get_tid());
+#endif
 		return 0;
 	}
-	aboat_resolve_flag = 0;
+	if ( rq->abort_flag ) {
+		aboat_resolve_flag = 0;
+		rq->abort_flag = 0;
+	}
 	_wakeup_resolve_thread();
 	for ( ; rq->status != RQ_RUN && rq->status != RQ_TIMEOUT ; ) {
+#ifdef RESOLVE_DEBUG
+ss_printf("exit-rs slp %i  -- %p\n",get_tid(),rq);
+#endif
+		_wakeup_resolve_thread();
 		sleep_task((int)rq,resolve_lock2);
 		lock_task(resolve_lock2);
+		if ( rq->abort_flag ) {
+			aboat_resolve_flag = 0;
+			rq->abort_flag = 0;
+		}
+#ifdef RESOLVE_DEBUG
+ss_printf("exit-rs wup %i  -- %p\n",get_tid(),rq);
+#endif
 	}
+#ifdef RESOLVE_DEBUG
+ss_printf("exit-rs END %i\n",get_tid());
+#endif
 	if ( rq->status == RQ_TIMEOUT )
 		return 0;
 	return -1;
@@ -518,6 +565,9 @@ RESOLVE_REQUEST_T * n;
 //			continue;
 			break;
 		}
+#ifdef RESOLVE_DEBUG
+ss_printf("RT %i\n",get_tid());
+#endif
 		n = resolve_que_head;
 		resolve_que_head = n->next;
 		if ( resolve_que_head == 0 )
@@ -525,11 +575,17 @@ RESOLVE_REQUEST_T * n;
 		unlock_task(resolve_lock2,"resolve_thread");
 
 		if ( n->a ) {
+#ifdef RESOLVE_DEBUG
+ss_printf("RT %i %x\n",get_tid(),n->a->d.v4);
+#endif
 			resolve_running = 1;
 			n->hp = intr_gethostbyaddr_rr(*n->a);
 			resolve_running = 0;
 		}
 		else if ( n->name ) {
+#ifdef RESOLVE_DEBUG
+ss_printf("RT %i %s\n",get_tid(),n->name);
+#endif
 			resolve_running = 1;
 			n->hp = intr_gethostbyname_rr(n->name);
 			resolve_running = 0;
@@ -537,6 +593,9 @@ RESOLVE_REQUEST_T * n;
 		else	n->hp = 0;
 
 
+#ifdef RESOLVE_DEBUG
+ss_printf("RT %i OK\n",get_tid());
+#endif
 		lock_task(resolve_lock2);
 		n->ok = 1;
 		wakeup_task((int)n);
@@ -551,6 +610,20 @@ RESOLVE_REQUEST_T n;
 	memset(&n,0,sizeof(n));
 	n.a = a;
 	n.name = name;
+#ifdef RESOLVE_DEBUG
+
+if ( a )
+ss_printf("RESOLVE REQUEST (%i) %x ",get_tid(),a->d.v4);
+else
+ss_printf("RESOLVE REQUEST (%i)",get_tid());
+if ( name )
+ss_printf("%s\n",name);
+else
+ss_printf("\n");
+if ( name[0] == 'y' )
+ss_printf("Y\n");
+#endif
+
 	lock_task(resolve_lock2);
 	if ( resolve_que_head ) {
 		resolve_que_tail->next = &n;
@@ -563,10 +636,18 @@ RESOLVE_REQUEST_T n;
 		create_task((void(*)(TKEY))resolve_thread,PRI_FETCH,0);
 	}
 	else wakeup_task((int)&resolve_tid);
+
+#ifdef RESOLVE_DEBUG
+ss_printf("WAIT LOOP %i\n",get_tid());
+#endif
+
 	for ( ; n.ok == 0 ; ) {
 		sleep_task((int)&n,resolve_lock2);
 		lock_task(resolve_lock2);
 	}
+#ifdef RESOLVE_DEBUG
+ss_printf("WAIT LOOP %i END\n",get_tid());
+#endif
 	unlock_task(resolve_lock2,"resolve_request");
 	return n.hp;
 }
@@ -578,9 +659,10 @@ HOST_ENTRY * ret, *new_ret;
 unsigned int t;
 RESOLVE_QUEUE rq;
 
-/*
+#ifdef RESOLVE_DEBUG
 ss_printf("r_get_hostbyaddr :: %x\n",a.d.v4);
-*/
+#endif
+
 
 	lock_task(resolve_lock2);
 retry2:
@@ -650,14 +732,18 @@ ok:
 }
 
 HOST_ENTRY *
-r_gethostbyname(char * name)
+r_gethostbyname(char * _name)
 {
+char * name;
 HOST_ENTRY * ret, * new_ret;
 unsigned int t;
 RESOLVE_QUEUE rq;
-/*
+
+	name = copy_str(_name);
+
+#ifdef RESOLVE_DEBUG
 ss_printf("r_get_hostbyname :: %s\n",name);
-*/
+#endif
 
 	lock_task(resolve_lock2);
 retry2:
@@ -723,9 +809,10 @@ ok:
 	if ( ret->flags & HEF_ERROR )
 		ret = 0;
 	unlock_task(resolve_lock2,"r_gethostbyname");
-/*
+#ifdef RESOLVE_DEBUG
 ss_printf("r_get_hostbyname :: %s OK\n",name);
-*/
+#endif
+	d_f_ree(name);
 	return ret;
 }
 
