@@ -28,7 +28,6 @@ extern "C" {
 #include	"v/v.h"
 #include 	"v/VgbQueryIndicate.h"
 
-
 #define BACK_COLOR_G_R	0xc0
 #define BACK_COLOR_G_G	0xc0
 #define BACK_COLOR_G_B	0xc0
@@ -269,6 +268,7 @@ QUERY_THREAD * qt;
 			sts.qth_focused = 1;
 			obj->set_queryindicate_status(&sts,VSF_QINDICATE_QTH_SET);
 			free_query_thread(sts.qth_set);
+			delete vq;
 		}
 		break;
 	case VMT_CUT:
@@ -546,11 +546,13 @@ VObjectStatus v_sts;
 				qw->qind_th = target;
 			}
 			qt->mask = 0;
+			qw->dirty = 1;
 		}
 		if ( qt->mask ) {
 			target->qth->flags &= ~qt->mask;
 			target->qth->flags |= qt->mask & qt->flags;
 			target->qth->mask = qt->mask;
+			qw->dirty = 1;
 
 			if ( target->qth->flags & QTF_ACTIVE )
 				v_sts.value = 0;
@@ -559,6 +561,7 @@ VObjectStatus v_sts;
 				target->eye_obj->set_status(&v_sts,VSF_VALUE);
 		}
 		else {
+			qw->dirty = 1;
 			duplicate_q_thread(target->qth,qt);
 			if ( target->obj )
 				set_q_thread_obj(s,qw,target);
@@ -571,6 +574,14 @@ VObjectStatus v_sts;
 	}
 }
 
+void
+free_tick(int d)
+{
+void * ptr;
+	ptr = (void*)d;
+	d_f_ree(ptr);
+}
+
 void 
 delete_qind_thread(VgbQueryIndicateWork * qw,int id)
 {
@@ -584,7 +595,10 @@ QIND_THREAD  **qind;
 	*qind = (*qind)->next;
 	free_query_thread(qt->qth);
 	qt->obj->destroy();
-	d_f_ree(qt);
+	
+	memset(qt,0,sizeof(*qt));
+	new_tick(free_tick,-60,(int)qt);
+	qw->dirty = 1;
 
 	if ( qw->from_flame == 0 )
 		insert_flame_ctl(qw,FC_DELETE,id,0);
@@ -753,6 +767,8 @@ VgbFlameRadarStatus r_sts;
 		qt->qth->flags |= QTF_ACTIVE;
 	else	qt->qth->flags &= ~QTF_ACTIVE;
 
+	qt->qw->dirty = 1;
+
 	f = qt->qw->flame;
 	if ( f == 0 )
 		return;
@@ -821,6 +837,9 @@ VObjectAppStatusAry * app;
 
 	err = initial_VExError(V_ER_NO_ERR,VSF_SPACING,0);
 
+	if ( in_flags & VSF_QINDICATE_DIRTY_BIT )
+		qw.dirty = in_sts->dirty;
+
 	info = 0;
 
 	copy_vobject_status(&_sts,(VObjectStatus*)s,flags);
@@ -893,7 +912,8 @@ VSysArgTranslator * vsat;
 		delete_qind_thread(&qw,qw.qind_th->qth->id);
 	vsat = qw.edit_event;
 	qw.edit_event = 0;
-	free_VSysArgTranslator(VFLT_DELETE,(void*)vsat);
+	if ( vsat )
+		free_VSysArgTranslator(VFLT_DELETE,(void*)vsat);
 	free_flame_ctl(qw.fctl);
 	qw.fctl = 0;
 }
@@ -941,6 +961,10 @@ VgbQueryIndicate::get_queryindicate_status(
 		sts->flame = qw.flame;
 		flags &= ~VSF_QINDICATE_FLAME;
 	}
+	if ( flags & VSF_QINDICATE_DIRTY_BIT ) {
+		sts->dirty = qw.dirty;
+		flags &= ~VSF_QINDICATE_DIRTY_BIT;
+	}
 	VM_OP_END
 	return initial_VExError(V_ER_NO_ERR,flags,0);
 }
@@ -1112,6 +1136,12 @@ FLAME_CTL * fc;
 	}
 	if ( fc )
 		_exec_flame_ctl(qw.flame,fc);
+	VM_OP_START_EX
+	if ( flags & VSF_QINDICATE_DIRTY_BIT ) {
+		qw.dirty = _sts->dirty;
+		flags &= ~VSF_QINDICATE_DIRTY_BIT;
+	}
+	VM_OP_END;
 	return initial_VExError(V_ER_NO_ERR,flags,0);
 }
 
@@ -1350,9 +1380,11 @@ VdataQThread * vqt;
 			delete xl;
 			return;
 		}
+		gc_push(0,0,"");
 		_xl = xl->get_VdataXL();
 		delete xl;
 		vqt = new VdataQThread(_xl);
+		gc_pop(0,0);
 		mData = vqt->get_VdataQThread(&err);
 		if ( err < 0 ) {
 			if ( erp )
@@ -1373,7 +1405,7 @@ VdataQThread * vqt;
 
 VdataQThread::~VdataQThread()
 {
-	if ( this->get_type() != &VIM_VdataXL )
+	if ( this->get_type() != &VIM_VdataQThread )
 		return;
 	if ( mData ) {
 		free_query_thread((QUERY_THREAD*)mData);
@@ -1391,10 +1423,12 @@ char * ret;
 			*erp = err;
 		return 0;
 	}
+	gc_push(0,0,"");
 	xl = q_thread_to_sexp((QUERY_THREAD*)mData,QTH_MAXIMUM_INFO);
 	_xl = new VdataXL(xl);
 	ret = _xl->get_VdataString();
 	delete _xl;
+	gc_pop(0,0);
 	if ( erp )
 		*erp = 0;
 	return ret;
@@ -1411,10 +1445,12 @@ L_CHAR * ret;
 			*erp = err;
 		return 0;
 	}
+	gc_push(0,0,"");
 	xl = q_thread_to_sexp((QUERY_THREAD*)mData,QTH_MAXIMUM_INFO);
 	_xl = new VdataXL(xl);
 	ret = _xl->get_VdataLString();
 	delete _xl;
+	gc_pop(0,0);
 	if ( erp )
 		*erp = 0;
 	return ret;
@@ -1456,14 +1492,14 @@ bool
 VdataQThread::clipboard_available(bool lock_flag)
 {
 Vdata * d;
-VdataXL * d2;
+VdataQThread * d2;
 int er;
 bool ret;
 ClipBoardList * c;
 	if ( lock_flag )
 		lock_task(cb_lock);
 	ret = false;
-	d2 = static_cast<VdataXL*>(check_clipboard_variation(&VIM_VdataQThread));
+	d2 = static_cast<VdataQThread*>(check_clipboard_variation(&VIM_VdataQThread));
 	if ( d2 ) {
 		ret = true;
 		goto end;
