@@ -91,6 +91,9 @@ init_vobj_VgbFlameStandard(XLISP_ENV *env)
 
 	set_env(env,l_string(std_cm,"VMT-SET-IWP"),
 		n_get_string(VMT_SET_IWP_STR));
+
+	set_env(env,l_string(std_cm,"VMT-HWF"),
+		n_get_string(VMT_HWF_STR));
 }
 
 char * _get_point_from_char(REAL1 * ret,char * str)
