@@ -230,6 +230,8 @@ VObject * obj;
 			if ( get_type(sym) != XLT_INTEGER )
 				continue;
 			obj = VObject::get_object_by_id(sym->integer.data);
+			if ( obj == 0 )
+				continue;
 			res = obj->get_object_by_name(name);
 			if ( res )
 				break;
@@ -277,6 +279,8 @@ VObject * obj;
 			if ( get_type(s) != XLT_INTEGER )
 				continue;
 			obj = VObject::get_object_by_id(s->integer.data);
+			if ( obj == 0 )
+				continue;
 			s = obj->get_object_by_name(name);
 			if ( s )
 				goto ok2;
@@ -1400,6 +1404,7 @@ int i;
 char buf[10];
 VObject * obj;
 VObjectStatus _sts;
+L_CHAR * nm;
 MODAL_EVENT_ARG * ag;
 	gc_push(0,0,"v_modal_dialog");
 	call = cons(n_get_symbol("param"),0);
@@ -1423,7 +1428,8 @@ MODAL_EVENT_ARG * ag;
 	ag = (MODAL_EVENT_ARG*)d_alloc(sizeof(*ag)*DIO_MAX);
 	memset(ag,0,sizeof(*ag)*DIO_MAX);
 	for ( i = 0 ; modal_event_func_table[i].name ; i ++ ) {
-		id = vobj_get_object_by_name(ret,l_string(std_cm,modal_event_func_table[i].name),0);
+		id = vobj_get_object_by_name(ret,nm=nl_copy_str(std_cm,modal_event_func_table[i].name),0);
+		d_f_ree(nm);
 		if ( get_type(id) != XLT_INTEGER )
 			continue;
 		obj = VObject::get_object_by_id(id->integer.data);
@@ -1447,6 +1453,9 @@ MODAL_EVENT_ARG * ag;
 		ss_printf("v_modal_dialog obj error\n");
 		goto end;
 	}
+	if ( io->pre_func )
+		(*io->pre_func)(io,ret);
+
 	lock_task(vobj_utils_lock);
 	_sts.visible = 1;
 	obj->set_status(&_sts,VSF_VISIBLE);
@@ -1459,6 +1468,9 @@ MODAL_EVENT_ARG * ag;
 	_sts.visible = 0;
 	obj->set_status(&_sts,VSF_VISIBLE);
 	unlock_task(vobj_utils_lock,"modal");
+	
+	if ( io->post_func )
+		(*io->post_func)(io,ret);
 	obj->destroy();
 	d_f_ree(ag);
 end:
