@@ -43,6 +43,9 @@ GC_THREAD *	gc_thread_hash[GC_THREAD_HASH_SIZE];
 
 void gc_gb_sexp();
 
+int depth_max,hash_max;
+GC_THREAD *	depth_max_thread;
+GC_STACK *	hash_max_stack;
 
 char *
 raw_copy_str(char * inp)
@@ -174,6 +177,7 @@ int tid,key;
 	if ( ret )
 		return ret;
 	ret = D_ALLOC(sizeof(*ret));
+	memset(ret,0,sizeof(*ret));
 	ret->tid = tid;
 	ret->stack = 0;
 	ret->next = gc_thread_hash[key];
@@ -225,15 +229,28 @@ void
 _push_stack(GC_THREAD * t,char * msg)
 {
 GC_STACK * st;
-int i;
+//int i;
 
 	st = D_ALLOC(sizeof(*st));
+	memset(st,0,sizeof(*st));
+/*
 	for ( i = 0 ; i < GC_LIST_HASH_SIZE ; i ++ )
 		st->hash[i] = 0;
+*/
+	st->thread = t;
+
 	st->msg = COPY_STR(msg);
+	
+	if ( t->stack )
+		st->child = t->stack;
+
 	st->parent = t->stack;
 	t->stack = st;
-
+	t->depth ++;
+	if ( depth_max < t->depth ) {
+		depth_max = t->depth;
+		depth_max_thread = t;
+	}
 }
 
 
@@ -246,6 +263,8 @@ GC_LIST * l2;
 	if ( t->stack ) {
 		st = t->stack;
 		t->stack = st->parent;
+		if ( t->stack )
+			t->stack->child = 0;
 		for ( i = 0 ; i < GC_LIST_HASH_SIZE ; i ++ ) {
 			for ( ; st->hash[i] ; ) {
 				l2 = st->hash[i];
@@ -256,6 +275,7 @@ GC_LIST * l2;
 		D_F_REE(st->msg);
 		D_F_REE(st);
 	}
+	t->depth --;
 	if ( t->stack == 0 )
 		_delete_thread(t);
 }
@@ -294,6 +314,11 @@ printf("lst->mem = %x\n",s);
 	lst->gc = gc;
 	lst->next = st->hash[key];
 	st->hash[key] = lst;
+	st->count ++;
+	if ( hash_max < st->count ) {
+		hash_max = st->count;
+		hash_max_stack = st;
+	}
 }
 
 
@@ -312,6 +337,11 @@ unsigned int key;
 	lst->gc = gc;
 	lst->next = st->hash[key];
 	st->hash[key] = lst;
+	st->count ++;
+	if ( hash_max < st->count ) {
+		hash_max = st->count;
+		hash_max_stack = st;
+	}
 }
 
 int
@@ -326,6 +356,7 @@ unsigned int key;
 			lst = *lp;
 			*lp = lst->next;
 			D_F_REE(lst);
+			st->count --;
 			return 0;
 		}
 	return -1;
@@ -354,6 +385,7 @@ XL_SEXP * sp;
 					continue;
 				lst = *lp;
 				*lp = lst->next;
+				st->count --;
 				D_F_REE(lst);
 				return 0;
 			}
