@@ -85,6 +85,8 @@ int interpreter_que_task;
 L_CHAR * lock_function;
 LOCK_FUNCTION_TYPE * lf_list;
 int dque_lock_cnt;
+HTID dque_task;
+int dque_task_point;
 
 int (* agent_open_xli)();
 int (* agent_close_xli)();
@@ -832,7 +834,7 @@ int pri;
 		ret = get_error(
 			s->h.file,
 			s->h.line,
-			XLE_SYSTEM_INTERRUPT,
+			XLE_SYSTEM_CANCEL,
 			l_string(std_cm,"cancel"),
 			0);
 	}
@@ -1421,6 +1423,21 @@ XL_INTERPRETER * xli;
 end:
 	{}
 }
+void
+close_interpreter_nowait(int id)
+{
+XL_INTERPRETER * xli;
+	lock_task(xli_lock);
+	xli = _search_xli_id(id);
+	if ( xli == 0 ) {
+		unlock_task(xli_lock,"close_interpreter");
+		goto end;
+	}
+	_close_interpreter(xli);
+	unlock_task(xli_lock,"close_interpreter");
+end:
+	{}
+}
 
 void
 close_self_interpreter()
@@ -2447,6 +2464,8 @@ XL_INTERPRETER * xli;
 
 		lock_task(xli_lock);
 		_dque_lock(0);
+dque_task = _get_tid();
+dque_task_point = 1;
 		unlock_task(xli_lock,"delay_thread");
 
 		w.flags = CDF_ALL&~(CDF_WAIT);
@@ -2463,14 +2482,18 @@ XL_INTERPRETER * xli;
 
 		lock_task(xli_lock);
 		interpreter_que_task --;
+dque_task_point = 2;
 		unlock_task(xli_lock,"delay_thread");
 
 		if ( w.result == CDT_WAIT_ERR ) {
+dque_task_point = 3;
 			create_task((void(*)(TKEY))delay_thread,0,PRI_XL_RELAY);
 			get_type(n->ret);
+dque_task_point = 4;
 		}
 		_reply(n->xli,n->line,n->ret);
 		lock_task(xli_lock);
+dque_task_point = 5;
 		n->xli->delay_que_cnt --;
 		n->xli->silent_cnt = 0;
 		_dque_unlock(0);
