@@ -357,7 +357,7 @@ int iid;
 			if ( buf.result_head == 0 ) {
 				iid = a->iid;
 				a->iid = 0;
-				close_interpreter(iid);
+				close_interpreter_nowait(iid);
 			}
 		}
 	}
@@ -1011,7 +1011,7 @@ XL_SEXP * ret;
 int iid;
 int retry_cnt;
 XL_SEXP * sa;
-
+L_CHAR * a_name,*ap;
 
 
 	lock_task(session_lock);
@@ -1087,14 +1087,16 @@ printf("ret C %i\n",get_tid());
 		set_attribute(sa,
 			l_string(std_cm,"client"),
 			l_string(std_cm,setagent_msg));
-
+	a_name = ll_copy_str(a->name);
+	for ( ap = a_name ; *ap && *ap != '#' ; ap ++ );
+	*ap = 0;
 
 
 	lock_xli_out_iid(a->iid);
 
 	ret = remote_query(a->iid,env,0,
 		List(sa,
-			get_string(a->name),
+			get_string(a_name),
 			get_string(login_mode),
 			-1));
 
